@@ -18,16 +18,12 @@ package org.kie.workbench.common.dmn.client.commands.expressions.types.dtable;
 
 import java.util.stream.IntStream;
 
-import org.kie.workbench.common.dmn.api.definition.v1_1.DecisionRule;
-import org.kie.workbench.common.dmn.api.definition.v1_1.DecisionTable;
-import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpression;
-import org.kie.workbench.common.dmn.api.definition.v1_1.UnaryTests;
-import org.kie.workbench.common.dmn.api.property.dmn.Description;
+import org.kie.workbench.common.dmn.api.definition.model.DecisionRule;
+import org.kie.workbench.common.dmn.api.definition.model.DecisionTable;
 import org.kie.workbench.common.dmn.client.commands.VetoExecutionCommand;
 import org.kie.workbench.common.dmn.client.commands.VetoUndoCommand;
 import org.kie.workbench.common.dmn.client.commands.util.CommandUtils;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.dtable.DecisionTableUIModelMapper;
-import org.kie.workbench.common.dmn.client.widgets.grid.model.DMNGridRow;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.command.AbstractCanvasCommand;
 import org.kie.workbench.common.stunner.core.client.canvas.command.AbstractCanvasGraphCommand;
@@ -40,16 +36,15 @@ import org.kie.workbench.common.stunner.core.graph.command.GraphCommandResultBui
 import org.kie.workbench.common.stunner.core.graph.command.impl.AbstractGraphCommand;
 import org.kie.workbench.common.stunner.core.rule.RuleViolation;
 import org.uberfire.ext.wires.core.grids.client.model.GridData;
+import org.uberfire.ext.wires.core.grids.client.model.GridRow;
 
 public class AddDecisionRuleCommand extends AbstractCanvasGraphCommand implements VetoExecutionCommand,
                                                                                   VetoUndoCommand {
 
-    public static final String DESCRIPTION_DEFAULT_VALUE = "A rule";
-
     private final DecisionTable dtable;
     private final DecisionRule rule;
     private final GridData uiModel;
-    private final DMNGridRow uiModelRow;
+    private final GridRow uiModelRow;
     private final int uiRowIndex;
     private final DecisionTableUIModelMapper uiModelMapper;
     private final org.uberfire.mvp.Command canvasOperation;
@@ -57,7 +52,7 @@ public class AddDecisionRuleCommand extends AbstractCanvasGraphCommand implement
     public AddDecisionRuleCommand(final DecisionTable dtable,
                                   final DecisionRule rule,
                                   final GridData uiModel,
-                                  final DMNGridRow uiModelRow,
+                                  final GridRow uiModelRow,
                                   final int uiRowIndex,
                                   final DecisionTableUIModelMapper uiModelMapper,
                                   final org.uberfire.mvp.Command canvasOperation) {
@@ -83,24 +78,6 @@ public class AddDecisionRuleCommand extends AbstractCanvasGraphCommand implement
                 dtable.getRule().add(uiRowIndex,
                                      rule);
 
-                for (int ie = 0; ie < dtable.getInput().size(); ie++) {
-                    final UnaryTests ut = new UnaryTests();
-                    ut.setText(AddInputClauseCommand.INPUT_CLAUSE_DEFAULT_VALUE);
-                    rule.getInputEntry().add(ut);
-                    ut.setParent(rule);
-                }
-                for (int oe = 0; oe < dtable.getOutput().size(); oe++) {
-                    final LiteralExpression le = new LiteralExpression();
-                    le.setText(AddOutputClauseCommand.OUTPUT_CLAUSE_DEFAULT_VALUE);
-                    rule.getOutputEntry().add(le);
-                    le.setParent(rule);
-                }
-                final Description d = new Description();
-                d.setValue(DESCRIPTION_DEFAULT_VALUE);
-                rule.setDescription(d);
-
-                rule.setParent(dtable);
-
                 return GraphCommandResultBuilder.SUCCESS;
             }
 
@@ -131,8 +108,10 @@ public class AddDecisionRuleCommand extends AbstractCanvasGraphCommand implement
                     uiModelMapper.fromDMNModel(uiRowIndex,
                                                columnIndex++);
                 }
-                uiModelMapper.fromDMNModel(uiRowIndex,
-                                           columnIndex);
+                for (int ani = 0; ani < dtable.getAnnotations().size(); ani++) {
+                    uiModelMapper.fromDMNModel(uiRowIndex,
+                                               columnIndex++);
+                }
 
                 updateRowNumbers();
                 updateParentInformation();
