@@ -21,8 +21,8 @@ import java.util.List;
 import java.util.stream.Collectors;
 import java.util.stream.IntStream;
 
-import org.kie.workbench.common.dmn.api.definition.v1_1.Binding;
-import org.kie.workbench.common.dmn.api.definition.v1_1.Invocation;
+import org.kie.workbench.common.dmn.api.definition.model.Binding;
+import org.kie.workbench.common.dmn.api.definition.model.Invocation;
 import org.kie.workbench.common.dmn.client.commands.VetoExecutionCommand;
 import org.kie.workbench.common.dmn.client.commands.VetoUndoCommand;
 import org.kie.workbench.common.dmn.client.commands.util.CommandUtils;
@@ -71,7 +71,7 @@ public class MoveRowsCommand extends AbstractCanvasGraphCommand implements VetoE
             @Override
             protected CommandResult<RuleViolation> check(final GraphCommandExecutionContext gcec) {
                 if (index == uiModel.getRowCount() - 1) {
-                    return GraphCommandResultBuilder.FAILED;
+                    return GraphCommandResultBuilder.failed();
                 }
                 return GraphCommandResultBuilder.SUCCESS;
             }
@@ -113,7 +113,7 @@ public class MoveRowsCommand extends AbstractCanvasGraphCommand implements VetoE
             @Override
             public CommandResult<CanvasViolation> allow(AbstractCanvasHandler context) {
                 if (index == uiModel.getRowCount() - 1) {
-                    return CanvasCommandResultBuilder.FAILED;
+                    return CanvasCommandResultBuilder.failed();
                 }
                 return CanvasCommandResultBuilder.SUCCESS;
             }
