@@ -26,6 +26,7 @@ import com.google.gwt.event.dom.client.ClickEvent;
 import elemental2.dom.HTMLElement;
 import org.jboss.errai.ui.client.local.api.elemental2.IsElement;
 import org.kie.workbench.common.dmn.client.docks.navigator.events.RefreshDecisionComponents;
+import org.kie.workbench.common.dmn.client.editors.expressions.util.NameUtils;
 import org.kie.workbench.common.dmn.client.editors.included.BaseIncludedModelActiveRecord;
 import org.kie.workbench.common.widgets.client.cards.CardComponent;
 import org.uberfire.client.mvp.UberElemental;
@@ -91,7 +92,7 @@ public abstract class BaseCardComponent<R extends BaseIncludedModelActiveRecord,
 
             final String oldName = getIncludedModel().getName();
 
-            getIncludedModel().setName(newName);
+            getIncludedModel().setName(NameUtils.normaliseName(newName));
 
             if (getIncludedModel().isValid()) {
                 getIncludedModel().update();
