@@ -35,8 +35,8 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
-import org.kie.workbench.common.dmn.api.definition.v1_1.Expression;
-import org.kie.workbench.common.dmn.api.definition.v1_1.LiteralExpression;
+import org.kie.workbench.common.dmn.api.definition.model.Expression;
+import org.kie.workbench.common.dmn.api.definition.model.LiteralExpression;
 import org.kie.workbench.common.dmn.api.property.dmn.Name;
 import org.kie.workbench.common.dmn.client.commands.factory.DefaultCanvasCommandFactory;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionEditorDefinition;
@@ -45,9 +45,9 @@ import org.kie.workbench.common.dmn.client.session.DMNEditorSession;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
 import org.kie.workbench.common.dmn.client.widgets.grid.ExpressionGridCache;
 import org.kie.workbench.common.dmn.client.widgets.grid.ExpressionGridCacheImpl;
-import org.kie.workbench.common.dmn.client.widgets.grid.columns.KeyboardOperationEscapeGridCell;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.ListSelectorView;
+import org.kie.workbench.common.dmn.client.widgets.grid.keyboard.KeyboardOperationEscapeGridCell;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
 import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
@@ -60,6 +60,7 @@ import org.kie.workbench.common.stunner.forms.client.event.RefreshFormProperties
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.Mock;
+import org.mockito.Mockito;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridData;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.impl.BaseGridWidgetKeyboardHandler;
@@ -76,11 +77,13 @@ import org.uberfire.mocks.EventSourceMock;
 
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.junit.Assert.assertEquals;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyInt;
-import static org.mockito.Matchers.anyObject;
-import static org.mockito.Matchers.anyString;
-import static org.mockito.Matchers.eq;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyBoolean;
+import static org.mockito.ArgumentMatchers.anyInt;
+import static org.mockito.ArgumentMatchers.anyObject;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
@@ -217,6 +220,7 @@ public class ExpressionEditorViewImplTest {
                                                                        any(Optional.class),
                                                                        any(HasExpression.class),
                                                                        any(Optional.class),
+                                                                       anyBoolean(),
                                                                        anyInt());
         doReturn(new BaseGridData()).when(editor).getModel();
 
@@ -247,6 +251,7 @@ public class ExpressionEditorViewImplTest {
                                                            any(Optional.class),
                                                            any(HasExpression.class),
                                                            any(Optional.class),
+                                                           anyBoolean(),
                                                            anyInt())).thenReturn(Optional.of(undefinedExpressionEditor));
 
         when(literalExpressionEditorDefinition.getModelClass()).thenReturn(Optional.of(new LiteralExpression()));
@@ -256,10 +261,11 @@ public class ExpressionEditorViewImplTest {
                                                          any(Optional.class),
                                                          any(HasExpression.class),
                                                          any(Optional.class),
+                                                         anyBoolean(),
                                                          anyInt())).thenReturn(Optional.of(literalExpressionEditor));
 
-        doAnswer((i) -> i.getArguments()[1]).when(translationService).format(anyString(), anyObject());
-        doAnswer((i) -> i.getArguments()[0]).when(translationService).getTranslation(anyString());
+        doAnswer((i) -> i.getArguments()[1]).when(translationService).format(Mockito.<String>any(), anyObject());
+        doAnswer((i) -> i.getArguments()[0]).when(translationService).getTranslation(Mockito.<String>any());
     }
 
     @Test
@@ -283,7 +289,6 @@ public class ExpressionEditorViewImplTest {
                      0.0);
 
         verify(gridPanel).addKeyDownHandler(any(BaseGridWidgetKeyboardHandler.class));
-        verify(gridPanel).add(gridLayer);
         verify(gridPanelContainer).clear();
         verify(gridPanelContainer).setWidget(gridPanel);
 
@@ -339,6 +344,34 @@ public class ExpressionEditorViewImplTest {
         verify(returnToLink).setTextContent(eq(RETURN_LINK));
     }
 
+    @Test
+    public void testSetExpression() {
+        final Optional<HasName> hasName = Optional.empty();
+
+        view.setExpression(NODE_UUID,
+                           hasExpression,
+                           hasName,
+                           false);
+
+        verify(gridLayer).add(expressionContainerArgumentCaptor.capture());
+        final ExpressionContainerGrid expressionContainer = (ExpressionContainerGrid) expressionContainerArgumentCaptor.getValue();
+        assertFalse(expressionContainer.isOnlyVisualChangeAllowed());
+    }
+
+    @Test
+    public void testSetExpressionWhenOnlyVisualChangeAllowed() {
+        final Optional<HasName> hasName = Optional.empty();
+
+        view.setExpression(NODE_UUID,
+                           hasExpression,
+                           hasName,
+                           true);
+
+        verify(gridLayer).add(expressionContainerArgumentCaptor.capture());
+        final ExpressionContainerGrid expressionContainer = (ExpressionContainerGrid) expressionContainerArgumentCaptor.getValue();
+        assertTrue(expressionContainer.isOnlyVisualChangeAllowed());
+    }
+
     @Test
     public void testSetExpressionDoesUpdateExpressionNameTextWhenHasNameIsNotEmpty() {
         final String NAME = "NAME";
@@ -349,7 +382,8 @@ public class ExpressionEditorViewImplTest {
 
         view.setExpression(NODE_UUID,
                            hasExpression,
-                           hasName);
+                           hasName,
+                           false);
 
         verify(expressionName).setTextContent(eq(NAME));
     }
@@ -360,7 +394,8 @@ public class ExpressionEditorViewImplTest {
 
         view.setExpression(NODE_UUID,
                            hasExpression,
-                           hasName);
+                           hasName,
+                           false);
 
         verify(expressionName, never()).setTextContent(any(String.class));
     }
@@ -373,7 +408,8 @@ public class ExpressionEditorViewImplTest {
 
         view.setExpression(NODE_UUID,
                            hasExpression,
-                           hasName);
+                           hasName,
+                           false);
 
         verify(expressionType).setTextContent(eq(LITERAL_EXPRESSION_DEFINITION_NAME));
     }
@@ -384,7 +420,8 @@ public class ExpressionEditorViewImplTest {
 
         view.setExpression(NODE_UUID,
                            hasExpression,
-                           hasName);
+                           hasName,
+                           false);
 
         verify(expressionType).setTextContent(eq("<" + UNDEFINED_EXPRESSION_DEFINITION_NAME + ">"));
     }
@@ -396,6 +433,13 @@ public class ExpressionEditorViewImplTest {
         verify(presenter).exit();
     }
 
+    @Test
+    public void testRefresh() {
+        view.refresh();
+
+        verify(gridLayer).batch();
+    }
+
     @Test
     public void testSetFocus() {
         view.setFocus();
