@@ -28,6 +28,7 @@ import com.ait.lienzo.client.core.shape.Viewport;
 import com.ait.lienzo.client.core.types.Transform;
 import com.ait.lienzo.test.LienzoMockitoTestRunner;
 import com.google.gwt.user.client.ui.AbsolutePanel;
+import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.junit.Before;
 import org.junit.Test;
@@ -35,10 +36,13 @@ import org.junit.runner.RunWith;
 import org.kie.workbench.common.dmn.api.definition.HasName;
 import org.kie.workbench.common.dmn.api.definition.NOPDomainObject;
 import org.kie.workbench.common.dmn.api.definition.model.BuiltinAggregator;
+import org.kie.workbench.common.dmn.api.definition.model.Context;
+import org.kie.workbench.common.dmn.api.definition.model.ContextEntry;
 import org.kie.workbench.common.dmn.api.definition.model.Decision;
 import org.kie.workbench.common.dmn.api.definition.model.DecisionRule;
 import org.kie.workbench.common.dmn.api.definition.model.DecisionTable;
 import org.kie.workbench.common.dmn.api.definition.model.HitPolicy;
+import org.kie.workbench.common.dmn.api.definition.model.InformationItem;
 import org.kie.workbench.common.dmn.api.definition.model.InformationItemPrimary;
 import org.kie.workbench.common.dmn.api.definition.model.InputClauseLiteralExpression;
 import org.kie.workbench.common.dmn.api.definition.model.OutputClause;
@@ -57,18 +61,21 @@ import org.kie.workbench.common.dmn.client.commands.expressions.types.dtable.Set
 import org.kie.workbench.common.dmn.client.commands.expressions.types.dtable.SetHitPolicyCommand;
 import org.kie.workbench.common.dmn.client.commands.factory.DefaultCanvasCommandFactory;
 import org.kie.workbench.common.dmn.client.commands.general.DeleteCellValueCommand;
-import org.kie.workbench.common.dmn.client.commands.general.DeleteHasNameCommand;
+import org.kie.workbench.common.dmn.client.commands.general.DeleteHasValueCommand;
 import org.kie.workbench.common.dmn.client.commands.general.SetCellValueCommand;
-import org.kie.workbench.common.dmn.client.commands.general.SetHasNameCommand;
+import org.kie.workbench.common.dmn.client.commands.general.SetHasValueCommand;
 import org.kie.workbench.common.dmn.client.commands.general.SetTypeRefCommand;
+import org.kie.workbench.common.dmn.client.docks.navigator.drds.DMNDiagramsSession;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.GridFactoryCommandUtils;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.dtable.hitpolicy.HitPolicyPopoverView;
-import org.kie.workbench.common.dmn.client.editors.types.NameAndDataTypePopoverView;
+import org.kie.workbench.common.dmn.client.editors.types.HasValueAndTypeRef;
+import org.kie.workbench.common.dmn.client.editors.types.ValueAndDataTypePopoverView;
+import org.kie.workbench.common.dmn.client.editors.types.common.ItemDefinitionUtils;
 import org.kie.workbench.common.dmn.client.graph.DMNGraphUtils;
 import org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants;
 import org.kie.workbench.common.dmn.client.session.DMNSession;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
-import org.kie.workbench.common.dmn.client.widgets.grid.columns.NameAndDataTypeHeaderMetaData;
+import org.kie.workbench.common.dmn.client.widgets.grid.columns.ValueAndDataTypeHeaderMetaData;
 import org.kie.workbench.common.dmn.client.widgets.grid.columns.factory.TextAreaSingletonDOMElementFactory;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.container.CellEditorControlsView;
 import org.kie.workbench.common.dmn.client.widgets.grid.controls.list.HasListSelectorControl;
@@ -79,6 +86,7 @@ import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellTuple;
 import org.kie.workbench.common.dmn.client.widgets.grid.model.GridCellValueTuple;
 import org.kie.workbench.common.dmn.client.widgets.layer.DMNGridLayer;
 import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
+import org.kie.workbench.common.stunner.core.client.ReadOnlyProvider;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.command.AbstractCanvasGraphCommand;
@@ -102,12 +110,13 @@ import org.kie.workbench.common.stunner.forms.client.event.RefreshFormProperties
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.Mock;
+import org.mockito.Mockito;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.model.GridData;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseBounds;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridCellValue;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridData;
-import org.uberfire.ext.wires.core.grids.client.model.impl.BaseHeaderMetaData;
+import org.uberfire.ext.wires.core.grids.client.widget.context.GridBodyCellEditContext;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.GridWidget;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.impl.GridLayerRedrawManager;
 import org.uberfire.mocks.EventSourceMock;
@@ -117,10 +126,9 @@ import static org.assertj.core.api.Assertions.assertThat;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyInt;
-import static org.mockito.Matchers.anyString;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyInt;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.atLeast;
 import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.mock;
@@ -198,9 +206,15 @@ public class DecisionTableGridTest {
     @Mock
     private SessionManager sessionManager;
 
+    @Mock
+    private ItemDefinitionUtils itemDefinitionUtils;
+
     @Mock
     private DMNDiagramUtils dmnDiagramUtils;
 
+    @Mock
+    private DMNDiagramsSession dmnDiagramsSession;
+
     @Mock
     private SessionCommandManager<AbstractCanvasHandler> sessionCommandManager;
 
@@ -247,7 +261,10 @@ public class DecisionTableGridTest {
     private HitPolicyPopoverView.Presenter hitPolicyEditor;
 
     @Mock
-    private NameAndDataTypePopoverView.Presenter headerEditor;
+    private ManagedInstance<ValueAndDataTypePopoverView.Presenter> headerEditors;
+
+    @Mock
+    private ValueAndDataTypePopoverView.Presenter headerEditor;
 
     @Mock
     private GridWidget parentGridWidget;
@@ -270,6 +287,12 @@ public class DecisionTableGridTest {
     @Mock
     private EventSourceMock<DomainObjectSelectionEvent> domainObjectSelectionEvent;
 
+    @Mock
+    private GridBodyCellEditContext gridBodyCellEditContext;
+
+    @Mock
+    private ReadOnlyProvider readOnlyProvider;
+
     @Captor
     private ArgumentCaptor<AddInputClauseCommand> addInputClauseCommandCaptor;
 
@@ -331,9 +354,11 @@ public class DecisionTableGridTest {
                                                             listSelector,
                                                             translationService,
                                                             hitPolicyEditor,
-                                                            headerEditor,
+                                                            headerEditors,
                                                             new DecisionTableEditorDefinitionEnricher(sessionManager,
-                                                                                                      new DMNGraphUtils(sessionManager, dmnDiagramUtils)));
+                                                                                                      new DMNGraphUtils(sessionManager, dmnDiagramUtils, dmnDiagramsSession),
+                                                                                                      itemDefinitionUtils),
+                                                            readOnlyProvider);
 
         expression = definition.getModelClass();
         definition.enrich(Optional.empty(), hasExpression, expression);
@@ -357,16 +382,19 @@ public class DecisionTableGridTest {
         when(graph.nodes()).thenReturn(Collections.singletonList(node));
 
         when(canvasHandler.getGraphIndex()).thenReturn(index);
-        when(index.get(anyString())).thenReturn(element);
+        when(index.get(Mockito.<String>any())).thenReturn(element);
         when(element.getContent()).thenReturn(mock(Definition.class));
         when(definitionUtils.getNameIdentifier(any())).thenReturn("name");
         when(canvasCommandFactory.updatePropertyValue(any(Element.class),
-                                                      anyString(),
+                                                      Mockito.<String>any(),
                                                       any())).thenReturn(updateElementPropertyCommand);
         when(updateElementPropertyCommand.execute(canvasHandler)).thenReturn(CanvasCommandResultBuilder.SUCCESS);
 
-        doAnswer((i) -> i.getArguments()[0].toString()).when(translationService).format(anyString());
-        doAnswer((i) -> i.getArguments()[0].toString()).when(translationService).getTranslation(anyString());
+        when(headerEditors.get()).thenReturn(headerEditor);
+        when(gridBodyCellEditContext.getRelativeLocation()).thenReturn(Optional.empty());
+
+        doAnswer((i) -> i.getArguments()[0].toString()).when(translationService).format(Mockito.<String>any());
+        doAnswer((i) -> i.getArguments()[0].toString()).when(translationService).getTranslation(Mockito.<String>any());
     }
 
     private void setupGrid(final Optional<HasName> hasName,
@@ -397,7 +425,7 @@ public class DecisionTableGridTest {
         assertTrue(uiModel.getColumns().get(0) instanceof DecisionTableRowNumberColumn);
         assertTrue(uiModel.getColumns().get(1) instanceof InputClauseColumn);
         assertTrue(uiModel.getColumns().get(2) instanceof OutputClauseColumn);
-        assertTrue(uiModel.getColumns().get(3) instanceof DescriptionColumn);
+        assertTrue(uiModel.getColumns().get(3) instanceof RuleAnnotationClauseColumn);
 
         assertEquals(1,
                      uiModel.getRowCount());
@@ -528,10 +556,10 @@ public class DecisionTableGridTest {
 
         assertEquals(1,
                      header.size());
-        assertTrue(header.get(0) instanceof BaseHeaderMetaData);
+        assertTrue(header.get(0) instanceof RuleAnnotationClauseColumnHeaderMetaData);
 
-        final BaseHeaderMetaData md = (BaseHeaderMetaData) header.get(0);
-        assertEquals(DMNEditorConstants.DecisionTableEditor_DescriptionColumnHeader,
+        final RuleAnnotationClauseColumnHeaderMetaData md = (RuleAnnotationClauseColumnHeaderMetaData) header.get(0);
+        assertEquals(DecisionTableDefaultValueUtilities.RULE_ANNOTATION_CLAUSE_PREFIX + "1",
                      md.getTitle());
     }
 
@@ -565,10 +593,14 @@ public class DecisionTableGridTest {
     }
 
     @Test
-    public void testGetItemsDescriptionColumn() {
+    public void testGetItemsRuleAnnotationColumn() {
         setupGrid(makeHasNameForDecision(), 0);
 
-        assertDefaultListItems(grid.getItems(0, 3), true);
+        final List<HasListSelectorControl.ListSelectorItem> items = grid.getItems(0, 3);
+
+        assertThat(items.size()).isEqualTo(10);
+        assertRuleAnnotationClauseItems(items.subList(0, 4));
+        assertDefaultListItems(items.subList(5, 10), true);
     }
 
     @Test
@@ -766,6 +798,30 @@ public class DecisionTableGridTest {
         verify(grid).deleteInputClause(eq(1));
     }
 
+    private void assertRuleAnnotationClauseItems(final List<HasListSelectorControl.ListSelectorItem> items) {
+        assertThat(items.size()).isEqualTo(4);
+        assertListSelectorHeaderItem(items.get(COLUMN_HEADER),
+                                     DMNEditorConstants.DecisionTableEditor_RuleAnnotationClauseHeader);
+        assertListSelectorTextItem(items.get(INSERT_COLUMN_BEFORE),
+                                   DMNEditorConstants.DecisionTableEditor_InsertRuleAnnotationClauseLeft,
+                                   true);
+        assertListSelectorTextItem(items.get(INSERT_COLUMN_AFTER),
+                                   DMNEditorConstants.DecisionTableEditor_InsertRuleAnnotationClauseRight,
+                                   true);
+        assertListSelectorTextItem(items.get(DELETE_COLUMN),
+                                   DMNEditorConstants.DecisionTableEditor_DeleteRuleAnnotationClause,
+                                   false);
+
+        grid.onItemSelected(items.get(INSERT_COLUMN_BEFORE));
+        verify(grid).addRuleAnnotationClause(eq(3));
+
+        grid.onItemSelected(items.get(INSERT_COLUMN_AFTER));
+        verify(grid).addRuleAnnotationClause(eq(4));
+
+        grid.onItemSelected(items.get(DELETE_COLUMN));
+        verify(grid).deleteRuleAnnotationClause(eq(3));
+    }
+
     private void assertOutputClauseItems(final List<HasListSelectorControl.ListSelectorItem> items) {
         assertThat(items.size()).isEqualTo(4);
         assertListSelectorHeaderItem(items.get(COLUMN_HEADER),
@@ -905,7 +961,6 @@ public class DecisionTableGridTest {
                                       eq(false));
 
         verifyEditHeaderCell(InputClauseColumnHeaderMetaData.class,
-                             Optional.of(DMNEditorConstants.DecisionTableEditor_EditInputClause),
                              0,
                              1);
 
@@ -993,7 +1048,6 @@ public class DecisionTableGridTest {
                                       eq(false));
 
         verifyEditHeaderCell(OutputClauseColumnHeaderMetaData.class,
-                             Optional.of(DMNEditorConstants.DecisionTableEditor_EditOutputClause),
                              1,
                              2);
 
@@ -1157,15 +1211,13 @@ public class DecisionTableGridTest {
         verify(gridLayer).batch();
     }
 
-    private void verifyEditHeaderCell(final Class<? extends NameAndDataTypeHeaderMetaData> headerMetaDataClass,
-                                      final Optional<String> editorTitle,
+    private void verifyEditHeaderCell(final Class<? extends ValueAndDataTypeHeaderMetaData> headerMetaDataClass,
                                       final int uiHeaderRowIndex,
                                       final int uiColumnIndex) {
         verify(headerEditor).bind(any(headerMetaDataClass),
                                   eq(uiHeaderRowIndex),
                                   eq(uiColumnIndex));
         verify(cellEditorControls).show(eq(headerEditor),
-                                        eq(editorTitle),
                                         anyInt(),
                                         anyInt());
     }
@@ -1222,36 +1274,37 @@ public class DecisionTableGridTest {
     public void testGetDisplayName() {
         setupGrid(makeHasNameForDecision(), 0);
 
-        assertThat(extractHeaderMetaData(0, 1).getName().getValue()).isEqualTo(INPUT_CLAUSE_NAME);
-        assertThat(extractHeaderMetaData(0, 2).getName().getValue()).isEqualTo(HASNAME_NAME);
+        assertThat(((Text) extractHeaderMetaData(0, 1).getValue()).getValue()).isEqualTo(INPUT_CLAUSE_NAME);
+        assertThat(((Name) extractHeaderMetaData(0, 2).getValue()).getValue()).isEqualTo(HASNAME_NAME);
 
         addOutputClause(3);
 
-        assertThat(extractHeaderMetaData(0, 2).getName().getValue()).isEqualTo(HASNAME_NAME);
-        assertThat(extractHeaderMetaData(1, 2).getName().getValue()).isEqualTo(OUTPUT_CLAUSE_NAME1);
-        assertThat(extractHeaderMetaData(0, 3).getName().getValue()).isEqualTo(HASNAME_NAME);
-        assertThat(extractHeaderMetaData(1, 3).getName().getValue()).isEqualTo(OUTPUT_CLAUSE_NAME2);
+        assertThat(((Name) extractHeaderMetaData(0, 2).getValue()).getValue()).isEqualTo(HASNAME_NAME);
+        assertThat(((Name) extractHeaderMetaData(1, 2).getValue()).getValue()).isEqualTo(OUTPUT_CLAUSE_NAME1);
+        assertThat(((Name) extractHeaderMetaData(0, 3).getValue()).getValue()).isEqualTo(HASNAME_NAME);
+        assertThat(((Name) extractHeaderMetaData(1, 3).getValue()).getValue()).isEqualTo(OUTPUT_CLAUSE_NAME2);
     }
 
-    private NameAndDataTypeHeaderMetaData extractHeaderMetaData(final int uiHeaderRowIndex,
-                                                                final int uiColumnIndex) {
+    private ValueAndDataTypeHeaderMetaData extractHeaderMetaData(final int uiHeaderRowIndex,
+                                                                 final int uiColumnIndex) {
         final GridColumn column = grid.getModel().getColumns().get(uiColumnIndex);
-        return (NameAndDataTypeHeaderMetaData) column.getHeaderMetaData().get(uiHeaderRowIndex);
+        return (ValueAndDataTypeHeaderMetaData) column.getHeaderMetaData().get(uiHeaderRowIndex);
     }
 
     @Test
+    @SuppressWarnings("unchecked")
     public void testSetDisplayNameWithNoChange() {
         setupGrid(makeHasNameForDecision(), 0);
 
-        assertHeaderMetaDataTest(0, 1, (md) -> md.setName(new Name(INPUT_CLAUSE_NAME)));
-        assertHeaderMetaDataTest(0, 2, (md) -> md.setName(new Name(HASNAME_NAME)));
+        assertHeaderMetaDataTest(0, 1, (md) -> md.setValue(new Text(INPUT_CLAUSE_NAME)));
+        assertHeaderMetaDataTest(0, 2, (md) -> md.setValue(new Name(HASNAME_NAME)));
 
         addOutputClause(3);
 
-        assertHeaderMetaDataTest(0, 2, (md) -> md.setName(new Name(HASNAME_NAME)));
-        assertHeaderMetaDataTest(1, 2, (md) -> md.setName(new Name(OUTPUT_CLAUSE_NAME1)));
-        assertHeaderMetaDataTest(0, 3, (md) -> md.setName(new Name(HASNAME_NAME)));
-        assertHeaderMetaDataTest(1, 3, (md) -> md.setName(new Name(OUTPUT_CLAUSE_NAME2)));
+        assertHeaderMetaDataTest(0, 2, (md) -> md.setValue(new Name(HASNAME_NAME)));
+        assertHeaderMetaDataTest(1, 2, (md) -> md.setValue(new Name(OUTPUT_CLAUSE_NAME1)));
+        assertHeaderMetaDataTest(0, 3, (md) -> md.setValue(new Name(HASNAME_NAME)));
+        assertHeaderMetaDataTest(1, 3, (md) -> md.setValue(new Name(OUTPUT_CLAUSE_NAME2)));
     }
 
     @Test
@@ -1259,9 +1312,9 @@ public class DecisionTableGridTest {
     public void testSetDisplayNameSingleInputClauseWithEmptyValue() {
         setupGrid(makeHasNameForDecision(), 0);
 
-        final Consumer<NameAndDataTypeHeaderMetaData> test = (md) -> md.setName(new Name());
+        final Consumer<ValueAndDataTypeHeaderMetaData> test = (md) -> md.setValue(new Text());
 
-        assertHeaderMetaDataTest(0, 1, test, DeleteHasNameCommand.class);
+        assertHeaderMetaDataTest(0, 1, test, DeleteHasValueCommand.class);
 
         compositeCommandCaptor.getValue().execute(canvasHandler);
         assertThat(expression.get().getInput().get(0).getInputExpression().getText()).isEqualTo(new Text());
@@ -1272,9 +1325,9 @@ public class DecisionTableGridTest {
     public void testSetDisplayNameSingleOutputClauseWithEmptyValue() {
         setupGrid(makeHasNameForDecision(), 0);
 
-        final Consumer<NameAndDataTypeHeaderMetaData> test = (md) -> md.setName(new Name());
+        final Consumer<ValueAndDataTypeHeaderMetaData> test = (md) -> md.setValue(new Name());
 
-        assertHeaderMetaDataTest(0, 2, test, DeleteHasNameCommand.class, DeleteHasNameCommand.class, UpdateElementPropertyCommand.class);
+        assertHeaderMetaDataTest(0, 2, test, DeleteHasValueCommand.class, DeleteHasValueCommand.class, UpdateElementPropertyCommand.class);
 
         compositeCommandCaptor.getValue().execute(canvasHandler);
         assertThat(hasExpression.getName().getValue()).isEqualTo("");
@@ -1285,7 +1338,7 @@ public class DecisionTableGridTest {
     public void testSetDisplayNameMultipleOutputClauseWithEmptyValue() {
         setupGrid(makeHasNameForDecision(), 0);
 
-        final Consumer<NameAndDataTypeHeaderMetaData> test = (md) -> md.setName(new Name());
+        final Consumer<ValueAndDataTypeHeaderMetaData> test = (md) -> md.setValue(new Name());
 
         addOutputClause(3);
 
@@ -1293,13 +1346,13 @@ public class DecisionTableGridTest {
     }
 
     @SuppressWarnings("unchecked")
-    private void assertDisplayNameMultipleOutputClause(final Consumer<NameAndDataTypeHeaderMetaData> test) {
+    private void assertDisplayNameMultipleOutputClause(final Consumer<ValueAndDataTypeHeaderMetaData> test) {
         final String defaultName = "defaultName";
 
         final ArgumentCaptor<CompositeCommand> compositeCommandCaptor1 = ArgumentCaptor.forClass(CompositeCommand.class);
         hasExpression.getName().setValue(defaultName);
         expression.get().getOutput().get(0).setName(defaultName);
-        assertHeaderMetaDataTest(0, 2, test, compositeCommandCaptor1, DeleteHasNameCommand.class, UpdateElementPropertyCommand.class);
+        assertHeaderMetaDataTest(0, 2, test, compositeCommandCaptor1, DeleteHasValueCommand.class, UpdateElementPropertyCommand.class);
 
         compositeCommandCaptor1.getValue().execute(canvasHandler);
         assertThat(hasExpression.getName().getValue()).isEqualTo("");
@@ -1308,7 +1361,7 @@ public class DecisionTableGridTest {
         final ArgumentCaptor<CompositeCommand> compositeCommandCaptor2 = ArgumentCaptor.forClass(CompositeCommand.class);
         hasExpression.getName().setValue(defaultName);
         expression.get().getOutput().get(0).setName(defaultName);
-        assertHeaderMetaDataTest(1, 2, test, compositeCommandCaptor2, DeleteHasNameCommand.class);
+        assertHeaderMetaDataTest(1, 2, test, compositeCommandCaptor2, DeleteHasValueCommand.class);
 
         compositeCommandCaptor2.getValue().execute(canvasHandler);
         assertThat(hasExpression.getName().getValue()).isEqualTo(defaultName);
@@ -1317,7 +1370,7 @@ public class DecisionTableGridTest {
         final ArgumentCaptor<CompositeCommand> compositeCommandCaptor3 = ArgumentCaptor.forClass(CompositeCommand.class);
         hasExpression.getName().setValue(defaultName);
         expression.get().getOutput().get(1).setName(defaultName);
-        assertHeaderMetaDataTest(0, 3, test, compositeCommandCaptor3, DeleteHasNameCommand.class, UpdateElementPropertyCommand.class);
+        assertHeaderMetaDataTest(0, 3, test, compositeCommandCaptor3, DeleteHasValueCommand.class, UpdateElementPropertyCommand.class);
 
         compositeCommandCaptor3.getValue().execute(canvasHandler);
         assertThat(hasExpression.getName().getValue()).isEqualTo("");
@@ -1326,7 +1379,7 @@ public class DecisionTableGridTest {
         final ArgumentCaptor<CompositeCommand> compositeCommandCaptor4 = ArgumentCaptor.forClass(CompositeCommand.class);
         hasExpression.getName().setValue(defaultName);
         expression.get().getOutput().get(1).setName(defaultName);
-        assertHeaderMetaDataTest(1, 3, test, compositeCommandCaptor4, DeleteHasNameCommand.class);
+        assertHeaderMetaDataTest(1, 3, test, compositeCommandCaptor4, DeleteHasValueCommand.class);
 
         compositeCommandCaptor4.getValue().execute(canvasHandler);
         assertThat(hasExpression.getName().getValue()).isEqualTo(defaultName);
@@ -1338,9 +1391,9 @@ public class DecisionTableGridTest {
     public void testSetDisplayNameSingleInputClauseWithNullValue() {
         setupGrid(makeHasNameForDecision(), 0);
 
-        final Consumer<NameAndDataTypeHeaderMetaData> test = (md) -> md.setName(null);
+        final Consumer<ValueAndDataTypeHeaderMetaData> test = (md) -> md.setValue(null);
 
-        assertHeaderMetaDataTest(0, 1, test, DeleteHasNameCommand.class);
+        assertHeaderMetaDataTest(0, 1, test, DeleteHasValueCommand.class);
 
         compositeCommandCaptor.getValue().execute(canvasHandler);
         assertThat(expression.get().getInput().get(0).getInputExpression().getText()).isEqualTo(new Text());
@@ -1351,9 +1404,9 @@ public class DecisionTableGridTest {
     public void testSetDisplayNameSingleOutputClauseWithNullValue() {
         setupGrid(makeHasNameForDecision(), 0);
 
-        final Consumer<NameAndDataTypeHeaderMetaData> test = (md) -> md.setName(null);
+        final Consumer<ValueAndDataTypeHeaderMetaData> test = (md) -> md.setValue(null);
 
-        assertHeaderMetaDataTest(0, 2, test, DeleteHasNameCommand.class, DeleteHasNameCommand.class, UpdateElementPropertyCommand.class);
+        assertHeaderMetaDataTest(0, 2, test, DeleteHasValueCommand.class, DeleteHasValueCommand.class, UpdateElementPropertyCommand.class);
 
         compositeCommandCaptor.getValue().execute(canvasHandler);
         assertThat(hasExpression.getName().getValue()).isEqualTo("");
@@ -1364,7 +1417,7 @@ public class DecisionTableGridTest {
     public void testSetDisplayNameMultipleOutputClauseWithNullValue() {
         setupGrid(makeHasNameForDecision(), 0);
 
-        final Consumer<NameAndDataTypeHeaderMetaData> test = (md) -> md.setName(null);
+        final Consumer<ValueAndDataTypeHeaderMetaData> test = (md) -> md.setValue(null);
 
         addOutputClause(3);
 
@@ -1376,9 +1429,9 @@ public class DecisionTableGridTest {
     public void testSetDisplayNameSingleInputClauseWithNonEmptyValue() {
         setupGrid(makeHasNameForDecision(), 0);
 
-        final Consumer<NameAndDataTypeHeaderMetaData> test = (md) -> md.setName(new Name(NAME_NEW));
+        final Consumer<ValueAndDataTypeHeaderMetaData> test = (md) -> md.setValue(new Text(NAME_NEW));
 
-        assertHeaderMetaDataTest(0, 1, test, SetHasNameCommand.class);
+        assertHeaderMetaDataTest(0, 1, test, SetHasValueCommand.class);
 
         compositeCommandCaptor.getValue().execute(canvasHandler);
         assertThat(expression.get().getInput().get(0).getInputExpression().getText()).isEqualTo(new Text(NAME_NEW));
@@ -1389,9 +1442,9 @@ public class DecisionTableGridTest {
     public void testSetDisplayNameSingleOutputClauseWithNonEmptyValue() {
         setupGrid(makeHasNameForDecision(), 0);
 
-        final Consumer<NameAndDataTypeHeaderMetaData> test = (md) -> md.setName(new Name(NAME_NEW));
+        final Consumer<ValueAndDataTypeHeaderMetaData> test = (md) -> md.setValue(new Name(NAME_NEW));
 
-        assertHeaderMetaDataTest(0, 2, test, SetHasNameCommand.class, SetHasNameCommand.class, UpdateElementPropertyCommand.class);
+        assertHeaderMetaDataTest(0, 2, test, SetHasValueCommand.class, SetHasValueCommand.class, UpdateElementPropertyCommand.class);
 
         compositeCommandCaptor.getValue().execute(canvasHandler);
         assertThat(hasExpression.getName()).isEqualTo(new Name(NAME_NEW));
@@ -1405,14 +1458,14 @@ public class DecisionTableGridTest {
 
         final String defaultName = "default-name";
 
-        final Consumer<NameAndDataTypeHeaderMetaData> test = (md) -> md.setName(new Name(NAME_NEW));
+        final Consumer<ValueAndDataTypeHeaderMetaData> test = (md) -> md.setValue(new Name(NAME_NEW));
 
         addOutputClause(3);
 
         final ArgumentCaptor<CompositeCommand> compositeCommandCaptor1 = ArgumentCaptor.forClass(CompositeCommand.class);
         hasExpression.getName().setValue(defaultName);
         expression.get().getOutput().get(0).setName(defaultName);
-        assertHeaderMetaDataTest(0, 2, test, compositeCommandCaptor1, SetHasNameCommand.class, UpdateElementPropertyCommand.class);
+        assertHeaderMetaDataTest(0, 2, test, compositeCommandCaptor1, SetHasValueCommand.class, UpdateElementPropertyCommand.class);
 
         compositeCommandCaptor1.getValue().execute(canvasHandler);
         assertThat(hasExpression.getName().getValue()).isEqualTo(NAME_NEW);
@@ -1421,7 +1474,7 @@ public class DecisionTableGridTest {
         final ArgumentCaptor<CompositeCommand> compositeCommandCaptor2 = ArgumentCaptor.forClass(CompositeCommand.class);
         hasExpression.getName().setValue(defaultName);
         expression.get().getOutput().get(0).setName(defaultName);
-        assertHeaderMetaDataTest(1, 2, test, compositeCommandCaptor2, SetHasNameCommand.class);
+        assertHeaderMetaDataTest(1, 2, test, compositeCommandCaptor2, SetHasValueCommand.class);
 
         compositeCommandCaptor2.getValue().execute(canvasHandler);
         assertThat(hasExpression.getName().getValue()).isEqualTo(defaultName);
@@ -1430,7 +1483,7 @@ public class DecisionTableGridTest {
         final ArgumentCaptor<CompositeCommand> compositeCommandCaptor3 = ArgumentCaptor.forClass(CompositeCommand.class);
         hasExpression.getName().setValue(defaultName);
         expression.get().getOutput().get(1).setName(defaultName);
-        assertHeaderMetaDataTest(0, 3, test, compositeCommandCaptor3, SetHasNameCommand.class, UpdateElementPropertyCommand.class);
+        assertHeaderMetaDataTest(0, 3, test, compositeCommandCaptor3, SetHasValueCommand.class, UpdateElementPropertyCommand.class);
 
         compositeCommandCaptor3.getValue().execute(canvasHandler);
         assertThat(hasExpression.getName().getValue()).isEqualTo(NAME_NEW);
@@ -1439,7 +1492,7 @@ public class DecisionTableGridTest {
         final ArgumentCaptor<CompositeCommand> compositeCommandCaptor4 = ArgumentCaptor.forClass(CompositeCommand.class);
         hasExpression.getName().setValue(defaultName);
         expression.get().getOutput().get(1).setName(defaultName);
-        assertHeaderMetaDataTest(1, 3, test, compositeCommandCaptor4, SetHasNameCommand.class);
+        assertHeaderMetaDataTest(1, 3, test, compositeCommandCaptor4, SetHasValueCommand.class);
 
         compositeCommandCaptor4.getValue().execute(canvasHandler);
         assertThat(hasExpression.getName().getValue()).isEqualTo(defaultName);
@@ -1469,7 +1522,7 @@ public class DecisionTableGridTest {
         final QName typeRef = new QName(QName.NULL_NS_URI,
                                         BuiltInType.DATE.getName());
 
-        final Consumer<NameAndDataTypeHeaderMetaData> test = (md) -> md.setTypeRef(typeRef);
+        final Consumer<ValueAndDataTypeHeaderMetaData> test = (md) -> md.setTypeRef(typeRef);
         final ArgumentCaptor<CanvasCommand> canvasCommandCaptor = ArgumentCaptor.forClass(CanvasCommand.class);
 
         assertHeaderMetaDataTest(0, 1, test, canvasCommandCaptor, SetTypeRefCommand.class);
@@ -1486,7 +1539,7 @@ public class DecisionTableGridTest {
         final QName typeRef = new QName(QName.NULL_NS_URI,
                                         BuiltInType.DATE.getName());
 
-        final Consumer<NameAndDataTypeHeaderMetaData> test = (md) -> md.setTypeRef(typeRef);
+        final Consumer<ValueAndDataTypeHeaderMetaData> test = (md) -> md.setTypeRef(typeRef);
 
         assertHeaderMetaDataTest(0, 2, test, SetTypeRefCommand.class, SetTypeRefCommand.class);
 
@@ -1504,7 +1557,7 @@ public class DecisionTableGridTest {
                                         BuiltInType.DATE.getName());
         final QName defaultTypeRef = new QName();
 
-        final Consumer<NameAndDataTypeHeaderMetaData> test = (md) -> md.setTypeRef(typeRef);
+        final Consumer<ValueAndDataTypeHeaderMetaData> test = (md) -> md.setTypeRef(typeRef);
 
         addOutputClause(3);
 
@@ -1549,7 +1602,7 @@ public class DecisionTableGridTest {
     public void testSetTypeRefWithoutChange() {
         setupGrid(makeHasNameForDecision(), 0);
 
-        final Consumer<NameAndDataTypeHeaderMetaData> test = (md) -> md.setTypeRef(new QName());
+        final Consumer<ValueAndDataTypeHeaderMetaData> test = (md) -> md.setTypeRef(new QName());
 
         assertHeaderMetaDataTest(0, 1, test);
         assertHeaderMetaDataTest(0, 2, test);
@@ -1565,7 +1618,7 @@ public class DecisionTableGridTest {
     @SuppressWarnings("unchecked")
     private void assertHeaderMetaDataTest(final int uiHeaderRowIndex,
                                           final int uiColumnIndex,
-                                          final Consumer<NameAndDataTypeHeaderMetaData> test,
+                                          final Consumer<ValueAndDataTypeHeaderMetaData> test,
                                           final Class... commands) {
         assertHeaderMetaDataTest(uiHeaderRowIndex,
                                  uiColumnIndex,
@@ -1577,7 +1630,7 @@ public class DecisionTableGridTest {
     @SuppressWarnings("unchecked")
     private void assertHeaderMetaDataTest(final int uiHeaderRowIndex,
                                           final int uiColumnIndex,
-                                          final Consumer<NameAndDataTypeHeaderMetaData> test,
+                                          final Consumer<ValueAndDataTypeHeaderMetaData> test,
                                           final ArgumentCaptor<? extends org.kie.workbench.common.stunner.core.command.Command> argumentCaptor,
                                           final Class... commands) {
         reset(sessionCommandManager);
@@ -1612,7 +1665,7 @@ public class DecisionTableGridTest {
 
         assertThat(dtable.getInput().get(0).getInputExpression().getText().getValue()).isEqualTo(grid.getModel().getColumns().get(1).getHeaderMetaData().get(0).getTitle());
 
-        extractHeaderMetaData(0, 1).setName(new Name(NAME_NEW));
+        extractHeaderMetaData(0, 1).setValue(new Text(NAME_NEW));
 
         verify(sessionCommandManager).execute(eq(canvasHandler),
                                               compositeCommandCaptor.capture());
@@ -1636,7 +1689,7 @@ public class DecisionTableGridTest {
 
         reset(sessionCommandManager);
 
-        extractHeaderMetaData(1, 2).setName(new Name(NAME_NEW));
+        extractHeaderMetaData(1, 2).setValue(new Name(NAME_NEW));
 
         verify(sessionCommandManager).execute(eq(canvasHandler),
                                               compositeCommandCaptor.capture());
@@ -1762,6 +1815,40 @@ public class DecisionTableGridTest {
         assertDomainObjectSelection(expression.get().getOutput().get(0));
     }
 
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testSelectHeaderMultipleOutputClauseColumnNestedContextEntry() {
+        //Mock nesting of DecisionTable in a ContextEntry
+        final Context context = new Context();
+        final ContextEntry contextEntry = new ContextEntry();
+        final InformationItem variable = new InformationItem();
+        contextEntry.setVariable(variable);
+        context.getContextEntry().add(contextEntry);
+        contextEntry.setExpression(expression.get());
+
+        this.hasExpression.setExpression(context);
+        this.grid = spy((DecisionTableGrid) definition.getEditor(parent,
+                                                                 Optional.empty(),
+                                                                 contextEntry,
+                                                                 makeHasNameForDecision(),
+                                                                 false,
+                                                                 1).get());
+
+        addOutputClause(2);
+
+        reset(domainObjectSelectionEvent);
+
+        grid.selectHeaderCell(0, DEFAULT_OUTPUT_CLAUSE_COLUMN_INDEX, false, false);
+
+        assertDomainObjectSelection(variable);
+
+        reset(domainObjectSelectionEvent);
+
+        grid.selectHeaderCell(1, DEFAULT_OUTPUT_CLAUSE_COLUMN_INDEX, false, false);
+
+        assertDomainObjectSelection(expression.get().getOutput().get(0));
+    }
+
     @Test
     public void testSelectHeaderDescriptionColumn() {
         setupGrid(makeHasNameForDecision(), 0);
@@ -1793,4 +1880,70 @@ public class DecisionTableGridTest {
 
         assertThat(grid.getModel().getSelectedCells()).containsOnly(new GridData.SelectedCell(0, 1));
     }
+
+    @Test
+    public void testMultipleInputClauseColumnHeaderEditorInstances() {
+        final ValueAndDataTypePopoverView.Presenter headerEditor2 = mock(ValueAndDataTypePopoverView.Presenter.class);
+
+        when(headerEditors.get()).thenReturn(headerEditor, headerEditor2);
+
+        setupGrid(makeHasNameForDecision(), 0);
+
+        addInputClause(2);
+
+        //Adding the column above shows the header editor by default, so reset it for the purpose of this test.
+        reset(headerEditor2);
+
+        final GridColumn uiColumn1 = grid.getModel().getColumns().get(1);
+        assertInputClauseColumnHeaderEditor(uiColumn1, headerEditor);
+
+        final GridColumn uiColumn2 = grid.getModel().getColumns().get(2);
+        assertInputClauseColumnHeaderEditor(uiColumn2, headerEditor2);
+    }
+
+    private void assertInputClauseColumnHeaderEditor(final GridColumn uiColumn,
+                                                     final ValueAndDataTypePopoverView.Presenter headerEditor) {
+        assertThat(uiColumn).isInstanceOf(InputClauseColumn.class);
+        final InputClauseColumn inputClauseColumn = (InputClauseColumn) uiColumn;
+        final GridColumn.HeaderMetaData inputClauseColumnHeaderMetaData = inputClauseColumn.getHeaderMetaData().get(0);
+        assertThat(inputClauseColumnHeaderMetaData).isInstanceOf(InputClauseColumnHeaderMetaData.class);
+        final InputClauseColumnHeaderMetaData inputClauseColumnHeaderMetaData1 = (InputClauseColumnHeaderMetaData) inputClauseColumnHeaderMetaData;
+        assertThat(inputClauseColumnHeaderMetaData1.getEditor()).isPresent();
+        //The only way to assert the editor was bound to the column is to try editing the header
+        inputClauseColumnHeaderMetaData1.edit(gridBodyCellEditContext);
+        verify(headerEditor).bind(any(HasValueAndTypeRef.class), anyInt(), anyInt());
+    }
+
+    @Test
+    public void testMultipleOutputClauseColumnHeaderEditorInstances() {
+        final ValueAndDataTypePopoverView.Presenter headerEditor2 = mock(ValueAndDataTypePopoverView.Presenter.class);
+
+        when(headerEditors.get()).thenReturn(headerEditor, headerEditor, headerEditor2);
+
+        setupGrid(makeHasNameForDecision(), 0);
+
+        addOutputClause(3);
+
+        //Adding the column above shows the header editor by default, so reset it for the purpose of this test.
+        reset(headerEditor2);
+
+        final GridColumn uiColumn1 = grid.getModel().getColumns().get(2);
+        assertOutputClauseColumnHeaderEditor(uiColumn1, headerEditor);
+
+        final GridColumn uiColumn2 = grid.getModel().getColumns().get(3);
+        assertOutputClauseColumnHeaderEditor(uiColumn2, headerEditor2);
+    }
+
+    private void assertOutputClauseColumnHeaderEditor(final GridColumn uiColumn,
+                                                      final ValueAndDataTypePopoverView.Presenter headerEditor) {
+        assertThat(uiColumn).isInstanceOf(OutputClauseColumn.class);
+        final OutputClauseColumn outputClauseColumn = (OutputClauseColumn) uiColumn;
+        final GridColumn.HeaderMetaData outputClauseColumnHeaderMetaData = outputClauseColumn.getHeaderMetaData().get(1);
+        assertThat(outputClauseColumnHeaderMetaData).isInstanceOf(OutputClauseColumnHeaderMetaData.class);
+        final OutputClauseColumnHeaderMetaData outputClauseColumnHeaderMetaData1 = (OutputClauseColumnHeaderMetaData) outputClauseColumnHeaderMetaData;
+        assertThat(outputClauseColumnHeaderMetaData1.getEditor()).isPresent();
+        //The only way to assert that editor was bound to the column is to try editing the header
+        outputClauseColumnHeaderMetaData1.edit(gridBodyCellEditContext);
+        verify(headerEditor).bind(any(HasValueAndTypeRef.class), anyInt(), anyInt());
+    }
 }
