@@ -20,15 +20,11 @@ import java.lang.annotation.Annotation;
 import java.util.function.Consumer;
 import java.util.function.Supplier;
 
-import javax.enterprise.event.Event;
-
-import com.google.gwt.user.client.Command;
 import com.google.gwtmockito.GwtMockitoTestRunner;
 import com.google.gwtmockito.WithClassesToStub;
 import elemental2.dom.HTMLElement;
-import org.guvnor.common.services.shared.metadata.model.Overview;
+import org.guvnor.messageconsole.client.console.widget.button.AlertsButtonMenuItemBuilder;
 import org.jboss.errai.common.client.ui.ElementWrapperWidget;
-import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
@@ -36,6 +32,7 @@ import org.kie.workbench.common.dmn.api.qualifiers.DMNEditor;
 import org.kie.workbench.common.dmn.client.commands.general.NavigateToExpressionEditorCommand;
 import org.kie.workbench.common.dmn.client.docks.navigator.DecisionNavigatorDock;
 import org.kie.workbench.common.dmn.client.docks.navigator.common.LazyCanvasFocusUtils;
+import org.kie.workbench.common.dmn.client.docks.navigator.drds.DMNDiagramsSession;
 import org.kie.workbench.common.dmn.client.editors.drd.DRDNameChanger;
 import org.kie.workbench.common.dmn.client.editors.expressions.ExpressionEditorView;
 import org.kie.workbench.common.dmn.client.editors.included.IncludedModelsPage;
@@ -47,59 +44,42 @@ import org.kie.workbench.common.dmn.client.editors.types.listview.common.DataTyp
 import org.kie.workbench.common.dmn.client.events.EditExpressionEvent;
 import org.kie.workbench.common.dmn.client.session.DMNEditorSession;
 import org.kie.workbench.common.dmn.client.widgets.codecompletion.MonacoFEELInitializer;
-import org.kie.workbench.common.dmn.project.client.resources.i18n.DMNProjectClientConstants;
 import org.kie.workbench.common.dmn.project.client.type.DMNDiagramResourceType;
 import org.kie.workbench.common.services.shared.resources.PerspectiveIds;
+import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionDiagramPresenter;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionPresenter;
-import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionEditorPresenter;
-import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionViewerPresenter;
-import org.kie.workbench.common.stunner.core.client.ReadOnlyProvider;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
 import org.kie.workbench.common.stunner.core.client.components.layout.LayoutHelper;
 import org.kie.workbench.common.stunner.core.client.components.layout.OpenDiagramLayoutExecutor;
-import org.kie.workbench.common.stunner.core.client.error.DiagramClientErrorHandler;
-import org.kie.workbench.common.stunner.core.client.i18n.ClientTranslationService;
-import org.kie.workbench.common.stunner.core.client.session.ClientSession;
-import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
-import org.kie.workbench.common.stunner.core.client.session.impl.ViewerSession;
-import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.documentation.DocumentationPage;
+import org.kie.workbench.common.stunner.core.validation.Violation;
 import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;
-import org.kie.workbench.common.stunner.kogito.client.editor.AbstractDiagramEditorMenuSessionItems;
-import org.kie.workbench.common.stunner.project.client.editor.AbstractProjectDiagramEditor;
-import org.kie.workbench.common.stunner.project.client.editor.AbstractProjectDiagramEditorCore;
 import org.kie.workbench.common.stunner.project.client.editor.AbstractProjectDiagramEditorTest;
-import org.kie.workbench.common.stunner.project.client.editor.ProjectDiagramEditorProxy;
-import org.kie.workbench.common.stunner.project.diagram.ProjectDiagram;
-import org.kie.workbench.common.stunner.project.diagram.ProjectMetadata;
-import org.kie.workbench.common.stunner.project.diagram.editor.ProjectDiagramResource;
 import org.kie.workbench.common.widgets.client.docks.DefaultEditorDock;
 import org.kie.workbench.common.widgets.client.search.component.SearchBarComponent;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.InOrder;
 import org.mockito.Mock;
+import org.mockito.Mockito;
+import org.uberfire.client.mvp.PlaceManager;
 import org.uberfire.client.views.pfly.multipage.MultiPageEditorSelectedPageEvent;
-import org.uberfire.client.workbench.widgets.common.ErrorPopupPresenter;
 import org.uberfire.client.workbench.widgets.multipage.MultiPageEditor;
 import org.uberfire.ext.editor.commons.client.menu.MenuItems;
-import org.uberfire.ext.widgets.core.client.editors.texteditor.TextEditorView;
 import org.uberfire.mocks.EventSourceMock;
+import org.uberfire.mvp.Command;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.mvp.impl.PathPlaceRequest;
-import org.uberfire.workbench.events.NotificationEvent;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.kie.workbench.common.dmn.project.client.editor.DMNDiagramEditor.DATA_TYPES_PAGE_INDEX;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyString;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.atLeast;
-import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.doNothing;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.inOrder;
@@ -116,18 +96,12 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
     @Mock
     private PlaceRequest currentPlace;
 
-    @Mock
-    private AbstractCanvasHandler canvasHandler;
-
     @Mock
     private SessionManager sessionManager;
 
     @Mock
     private DMNEditorSession dmnEditorSession;
 
-    @Mock
-    private DMNEditorSession defaultEditorSession;
-
     @Mock
     private SessionCommandManager<AbstractCanvasHandler> sessionCommandManager;
 
@@ -161,8 +135,6 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
     @Mock
     private MultiPageEditor multiPage;
 
-    private DMNDiagramEditor diagramEditor;
-
     @Mock
     private DefaultEditorDock docks;
 
@@ -184,9 +156,6 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
     @Mock
     private ElementWrapperWidget searchBarComponentWidget;
 
-    @Mock
-    private ReadOnlyProvider readOnlyProvider;
-
     @Mock
     private HTMLElement drdNameChangerElement;
 
@@ -199,9 +168,26 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
     @Mock
     private ElementWrapperWidget drdNameWidget;
 
+    @Mock
+    private DMNDiagramsSession dmnDiagramsSession;
+
     @Captor
     private ArgumentCaptor<Consumer<String>> errorConsumerCaptor;
 
+    @Mock
+    private PlaceManager placeManager;
+
+    @Mock
+    private AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder;
+
+    @Mock
+    private SessionPresenter.View presenterView;
+
+    @Mock
+    private SessionDiagramPresenter presenter;
+
+    private DMNDiagramEditor diagramEditor;
+
     @Before
     public void before() {
         when(kieView.getMultiPage()).thenReturn(multiPage);
@@ -210,44 +196,34 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
     @Override
     public void setUp() {
         super.setUp();
+
         when(sessionManager.getCurrentSession()).thenReturn(dmnEditorSession);
-        when(sessionEditorPresenter.getInstance()).thenReturn(dmnEditorSession);
+        when(stunnerEditor.getSession()).thenReturn(dmnEditorSession);
         when(dmnEditorSession.getExpressionEditor()).thenReturn(expressionEditor);
         when(dmnEditorSession.getCanvasHandler()).thenReturn(canvasHandler);
         when(canvasHandler.getDiagram()).thenReturn(diagram);
         when(searchBarComponent.getView()).thenReturn(searchBarComponentView);
         when(searchBarComponentView.getElement()).thenReturn(searchBarComponentViewElement);
         when(drdNameChanger.getElement()).thenReturn(drdNameChangerElement);
-        doReturn(drdNameWidget).when(diagramEditor).getWidget(drdNameChangerElement);
-    }
+        when(dmnProjectMenuSessionItems.setErrorConsumer(Mockito.<Consumer>any())).thenReturn(dmnProjectMenuSessionItems);
+        when(dmnProjectMenuSessionItems.setLoadingCompleted(Mockito.<org.uberfire.mvp.Command>any())).thenReturn(dmnProjectMenuSessionItems);
+        when(dmnProjectMenuSessionItems.setLoadingStarts(Mockito.<Command>any())).thenReturn(dmnProjectMenuSessionItems);
 
-    @Override
-    protected DMNDiagramResourceType mockResourceType() {
         final DMNDiagramResourceType resourceType = mock(DMNDiagramResourceType.class);
         when(resourceType.getSuffix()).thenReturn("dmn");
         when(resourceType.getShortName()).thenReturn("DMN");
-        return resourceType;
-    }
 
-    @SuppressWarnings("unchecked")
-    @Override
-    protected AbstractProjectDiagramEditor createDiagramEditor() {
         diagramEditor = spy(new DMNDiagramEditor(view,
-                                                 xmlEditorView,
-                                                 sessionEditorPresenters,
-                                                 sessionViewerPresenters,
                                                  onDiagramFocusEvent,
                                                  onDiagramLostFocusEvent,
-                                                 notificationEvent,
-                                                 errorPopupPresenter,
-                                                 diagramClientErrorHandler,
                                                  documentationView,
-                                                 (DMNDiagramResourceType) getResourceType(),
-                                                 (DMNEditorMenuSessionItems) getMenuSessionItems(),
+                                                 resourceType,
+                                                 dmnProjectMenuSessionItems,
                                                  projectMessagesListener,
                                                  translationService,
-                                                 clientProjectDiagramService,
+                                                 projectDiagramServices,
                                                  projectDiagramResourceServiceCaller,
+                                                 stunnerEditor,
                                                  sessionManager,
                                                  sessionCommandManager,
                                                  refreshFormPropertiesEvent,
@@ -259,70 +235,33 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
                                                  editorSearchIndex,
                                                  searchBarComponent,
                                                  feelInitializer,
-                                                 readOnlyProvider,
                                                  drdNameChanger,
-                                                 lazyCanvasFocusUtils) {
+                                                 lazyCanvasFocusUtils,
+                                                 dmnDiagramsSession) {
             {
                 docks = DMNDiagramEditorTest.this.docks;
                 fileMenuBuilder = DMNDiagramEditorTest.this.fileMenuBuilder;
                 workbenchContext = DMNDiagramEditorTest.this.workbenchContext;
                 projectController = DMNDiagramEditorTest.this.projectController;
                 versionRecordManager = DMNDiagramEditorTest.this.versionRecordManager;
-                sessionEditorPresenters = DMNDiagramEditorTest.this.sessionEditorPresenters;
                 alertsButtonMenuItemBuilder = DMNDiagramEditorTest.this.alertsButtonMenuItemBuilder;
                 kieView = DMNDiagramEditorTest.this.kieView;
                 overviewWidget = DMNDiagramEditorTest.this.overviewWidget;
-                notification = DMNDiagramEditorTest.this.notificationEvent;
+                notification = DMNDiagramEditorTest.this.notification;
                 placeManager = DMNDiagramEditorTest.this.placeManager;
-                changeTitleNotification = DMNDiagramEditorTest.this.changeTitleNotificationEvent;
+                changeTitleNotification = DMNDiagramEditorTest.this.changeTitleNotification;
                 savePopUpPresenter = DMNDiagramEditorTest.this.savePopUpPresenter;
-            }
-
-            @Override
-            protected AbstractProjectDiagramEditorCore<ProjectMetadata, ProjectDiagram, ProjectDiagramResource, ProjectDiagramEditorProxy<ProjectDiagramResource>> makeCore(final AbstractProjectDiagramEditor.View view,
-                                                                                                                                                                            final TextEditorView xmlEditorView,
-                                                                                                                                                                            final Event<NotificationEvent> notificationEvent,
-                                                                                                                                                                            final ManagedInstance<SessionEditorPresenter<EditorSession>> editorSessionPresenterInstances,
-                                                                                                                                                                            final ManagedInstance<SessionViewerPresenter<ViewerSession>> viewerSessionPresenterInstances,
-                                                                                                                                                                            final AbstractDiagramEditorMenuSessionItems<?> menuSessionItems,
-                                                                                                                                                                            final ErrorPopupPresenter errorPopupPresenter,
-                                                                                                                                                                            final DiagramClientErrorHandler diagramClientErrorHandler,
-                                                                                                                                                                            final ClientTranslationService translationService) {
-                presenterCore = spy(super.makeCore(view,
-                                                   xmlEditorView,
-                                                   notificationEvent,
-                                                   editorSessionPresenterInstances,
-                                                   viewerSessionPresenterInstances,
-                                                   menuSessionItems,
-                                                   errorPopupPresenter,
-                                                   diagramClientErrorHandler,
-                                                   translationService));
-                this.saveAndRenameCommandBuilder = saveAndRenameCommandBuilderMock;
-                return presenterCore;
-            }
-
-            @Override
-            public boolean isReadOnly() {
-                return DMNDiagramEditorTest.this.isReadOnly;
-            }
-
-            @Override
-            ElementWrapperWidget<?> getWidget(final HTMLElement element) {
-                return searchBarComponentWidget;
-            }
-
-            @Override
-            public SessionPresenter<? extends ClientSession, ?, Diagram> getSessionPresenter() {
-                return sessionViewerPresenter;
+                saveAndRenameCommandBuilder = DMNDiagramEditorTest.this.saveAndRenameCommandBuilder;
             }
         });
-
-        return diagramEditor;
-    }
-
-    @Override
-    protected AbstractDiagramEditorMenuSessionItems getMenuSessionItems() {
-        return dmnProjectMenuSessionItems;
+        doReturn(searchBarComponentWidget).when(diagramEditor).getWidget(any());
+        doReturn(drdNameWidget).when(diagramEditor).getWidget(eq(drdNameChangerElement));
+        doNothing().when(stunnerEditor).focus();
+        doNothing().when(stunnerEditor).lostFocus();
+        when(presenter.getView()).thenReturn(presenterView);
+        when(stunnerEditor.getPresenter()).thenReturn(presenter);
+        when(stunnerEditor.getCanvasHandler()).thenReturn(canvasHandler);
+        when(stunnerEditor.getView()).thenReturn(view);
     }
 
     @Test
@@ -342,7 +281,8 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
         errorConsumerCaptor.getValue().accept("ERROR");
 
         verify(view).hideBusyIndicator();
-        verify(errorPopupPresenter, never()).showMessage(anyString());
+        verify(stunnerEditor, never()).showMessage(Mockito.<String>any());
+        verify(stunnerEditor, never()).showError(Mockito.<String>any());
         verify(editorSearchIndex).setIsDataTypesTabActiveSupplier(isDataTypesTabActiveSupplier);
         verify(editorSearchIndex).setCurrentAssetHashcodeSupplier(currentContentHashSupplier);
     }
@@ -361,28 +301,19 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
 
     @Test
     public void testOnStartup() {
-        doNothing().when(diagramEditor).superDoStartUp(filePath, currentPlace);
-
         diagramEditor.onStartup(filePath, currentPlace);
-
-        verify(diagramEditor).superDoStartUp(filePath, currentPlace);
-        verify(decisionNavigatorDock).init(PerspectiveIds.LIBRARY);
+        verify(decisionNavigatorDock).init(eq(PerspectiveIds.LIBRARY));
     }
 
     @Test
     public void testOnClose() {
-        doNothing().when(diagramEditor).superDoClose();
-
         diagramEditor.onClose();
-
-        verify(diagramEditor).superDoClose();
         verify(dataTypesPage).disableShortcuts();
         verify(kieView).clear();
     }
 
     @Test
     public void testInitialiseKieEditorForSession() {
-        doNothing().when(diagramEditor).superInitialiseKieEditorForSession(any());
 
         diagramEditor.initialiseKieEditorForSession(diagram);
 
@@ -391,61 +322,88 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
         verify(diagramEditor).setupSearchComponent();
     }
 
+    @Test
+    public void testInitialiseKieEditorForSessionWhenInitializingKieEditorForSessionThenDiagramAlreadyLoaded() {
+        final InOrder inOrder = inOrder(diagramEditor);
+        diagramEditor.initialiseKieEditorForSession(diagram);
+        inOrder.verify(diagramEditor).onDiagramLoad();
+        inOrder.verify(diagramEditor).superInitialiseKieEditorForSession(any());
+    }
+
     @Test
     public void testSetupSearchComponent() {
-
         diagramEditor.setupSearchComponent();
-
         verify(searchBarComponent).init(editorSearchIndex);
         verify(multiPage).addTabBarWidget(searchBarComponentWidget);
     }
 
-    @Test
-    public void testOnDiagramLoadWhenCanvasHandlerIsNotNull() {
-        when(sessionManager.getCurrentSession()).thenReturn(dmnEditorSession);
-        when(dmnEditorSession.getCanvasHandler()).thenReturn(canvasHandler);
-        when(canvasHandler.getDiagram()).thenReturn(diagram);
-
-        open();
-
-        verify(decisionNavigatorDock).reload();
-        verify(expressionEditor).setToolbarStateHandler(any(DMNProjectToolbarStateHandler.class));
-        verify(dataTypesPage).reload();
-        verify(layoutHelper).applyLayout(diagram, layoutExecutor);
-        verify(includedModelsPage).reload();
-        verify(lazyCanvasFocusUtils).releaseFocus();
-    }
-
-    @Test
-    @SuppressWarnings("unchecked")
-    public void testOnDiagramLoadWhenCanvasHandlerIsNull() {
-        diagramEditor.onDiagramLoad();
-
-        verify(expressionEditor, never()).setToolbarStateHandler(any(DMNProjectToolbarStateHandler.class));
-        verify(decisionNavigatorDock, never()).reload();
-        verify(decisionNavigatorDock, never()).open();
-        verify(dataTypesPage, never()).reload();
-        verify(includedModelsPage, never()).reload();
-        verify(lazyCanvasFocusUtils, never()).releaseFocus();
-    }
-
     @Test
     public void testOnFocus() {
-        doNothing().when(diagramEditor).superDoFocus();
-
+        when(stunnerEditor.isClosed()).thenReturn(false);
         diagramEditor.onFocus();
-
-        verify(diagramEditor).superDoFocus();
+        verify(stunnerEditor).focus();
+        verify(stunnerEditor, never()).lostFocus();
         verify(diagramEditor).onDiagramLoad();
         verify(dataTypesPage).onFocus();
+        verify(dataTypesPage, never()).onLostFocus();
         verify(dataTypesPage).enableShortcuts();
+        verify(dataTypesPage, never()).disableShortcuts();
     }
 
     @Test
     public void testOnLostFocus() {
+        when(stunnerEditor.isClosed()).thenReturn(false);
         diagramEditor.onLostFocus();
-
+        verify(stunnerEditor).lostFocus();
+        verify(stunnerEditor, never()).focus();
         verify(dataTypesPage).onLostFocus();
+        verify(dataTypesPage, never()).onFocus();
+    }
+
+    @Test
+    public void testOnDataTypePageNavTabActiveEvent() {
+        diagramEditor.onDataTypePageNavTabActiveEvent(mock(DataTypePageTabActiveEvent.class));
+        verify(multiPage).selectPage(DATA_TYPES_PAGE_INDEX);
+    }
+
+    @Test
+    public void testOnDataTypeEditModeToggleWhenEditModeIsEnabled() {
+        final DataTypeEditModeToggleEvent editModeToggleEvent = mock(DataTypeEditModeToggleEvent.class);
+        doNothing().when(diagramEditor).disableMenuItem(any());
+        when(editModeToggleEvent.isEditModeEnabled()).thenReturn(true);
+        diagramEditor.getOnDataTypeEditModeToggleCallback(editModeToggleEvent).onInvoke();
+        verify(diagramEditor).disableMenuItem(MenuItems.SAVE);
+    }
+
+    @Test
+    public void testOnDataTypeEditModeToggleWhenEditModeIsNotEnabled() {
+        final DataTypeEditModeToggleEvent editModeToggleEvent = mock(DataTypeEditModeToggleEvent.class);
+        doNothing().when(diagramEditor).enableMenuItem(any());
+        when(editModeToggleEvent.isEditModeEnabled()).thenReturn(false);
+        diagramEditor.getOnDataTypeEditModeToggleCallback(editModeToggleEvent).onInvoke();
+        verify(diagramEditor).enableMenuItem(MenuItems.SAVE);
+    }
+
+    @Test
+    public void testShowDocks() {
+        diagramEditor.showDocks();
+        verify(decisionNavigatorDock).open();
+        verify(docks).show();
+    }
+
+    @Test
+    public void testHideDocks() {
+        diagramEditor.hideDocks();
+        verify(decisionNavigatorDock).close();
+        verify(decisionNavigatorDock).resetContent();
+        verify(docks).hide();
+    }
+
+    @Override
+    public void testDocksQualifiers() {
+        final Annotation[] qualifiers = diagramEditor.getDockQualifiers();
+        assertEquals(1, qualifiers.length);
+        assertEquals(DMNEditor.class, qualifiers[0].annotationType());
     }
 
     @Test
@@ -454,128 +412,51 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
         when(sessionManager.getCurrentSession()).thenReturn(dmnEditorSession);
         when(dmnEditorSession.getCanvasHandler()).thenReturn(canvasHandler);
 
-        open();
+        diagramEditor.open(diagram);
 
         diagramEditor.onEditExpressionEvent(editExpressionEvent);
 
         verify(searchBarComponent).disableSearch();
         verify(sessionCommandManager).execute(eq(canvasHandler),
-                                              any(NavigateToExpressionEditorCommand.class));
+                                              Mockito.<NavigateToExpressionEditorCommand>any());
     }
 
     @Test
-    public void testOnDataTypePageNavTabActiveEvent() {
-        diagramEditor.onDataTypePageNavTabActiveEvent(mock(DataTypePageTabActiveEvent.class));
+    public void testOnDiagramLoadWhenCanvasHandlerIsNotNull() {
+        when(sessionManager.getCurrentSession()).thenReturn(dmnEditorSession);
+        when(dmnEditorSession.getCanvasHandler()).thenReturn(canvasHandler);
 
-        verify(multiPage).selectPage(DATA_TYPES_PAGE_INDEX);
-    }
+        diagramEditor.open(diagram);
 
-    @Test
-    public void testOnDataTypeEditModeToggleWhenEditModeIsEnabled() {
-        final DataTypeEditModeToggleEvent editModeToggleEvent = mock(DataTypeEditModeToggleEvent.class);
-
-        doNothing().when(diagramEditor).disableMenuItem(any());
-        when(editModeToggleEvent.isEditModeEnabled()).thenReturn(true);
-
-        diagramEditor.getOnDataTypeEditModeToggleCallback(editModeToggleEvent).onInvoke();
-
-        verify(diagramEditor).disableMenuItem(MenuItems.SAVE);
-    }
-
-    @Test
-    public void testOnDataTypeEditModeToggleWhenEditModeIsNotEnabled() {
-        final DataTypeEditModeToggleEvent editModeToggleEvent = mock(DataTypeEditModeToggleEvent.class);
-
-        doNothing().when(diagramEditor).enableMenuItem(any());
-        when(editModeToggleEvent.isEditModeEnabled()).thenReturn(false);
-
-        diagramEditor.getOnDataTypeEditModeToggleCallback(editModeToggleEvent).onInvoke();
-
-        verify(diagramEditor).enableMenuItem(MenuItems.SAVE);
-    }
-
-    @Test
-    public void testShowDocks() {
-        diagramEditor.showDocks();
-
-        verify(decisionNavigatorDock).open();
-        verify(docks).show();
-    }
-
-    @Test
-    public void testHideDocks() {
-        diagramEditor.hideDocks();
-
-        verify(decisionNavigatorDock).close();
-        verify(decisionNavigatorDock).resetContent();
-        verify(docks).hide();
-    }
-
-    @Override
-    public void testDocksQualifiers() {
-        final Annotation[] qualifiers = presenter.getDockQualifiers();
-        assertEquals(1, qualifiers.length);
-        assertEquals(DMNEditor.class, qualifiers[0].annotationType());
+        verify(decisionNavigatorDock, atLeast(1)).reload();
+        verify(expressionEditor, atLeast(1)).setToolbarStateHandler(Mockito.<DMNProjectToolbarStateHandler>any());
+        verify(dataTypesPage, atLeast(1)).reload();
+        verify(layoutHelper).applyLayout(diagram, layoutExecutor);
+        verify(includedModelsPage, atLeast(1)).reload();
+        verify(lazyCanvasFocusUtils, atLeast(1)).releaseFocus();
     }
 
     @Test
     @SuppressWarnings("unchecked")
-    public void testParsingErrorMessage() {
-        doAnswer(i -> i.getArguments()[0]).when(translationService).getValue(anyString());
+    public void testOnDiagramLoadWhenCanvasHandlerIsNull() {
+        when(stunnerEditor.getCanvasHandler()).thenReturn(null);
+        diagramEditor.onDiagramLoad();
 
-        final String xml = "xml";
-
-        openInvalidFile(xml);
-
-        final ArgumentCaptor<NotificationEvent> notificationEventCaptor = ArgumentCaptor.forClass(NotificationEvent.class);
-        verify(notificationEvent).fire(notificationEventCaptor.capture());
-
-        final NotificationEvent notificationEvent = notificationEventCaptor.getValue();
-        assertEquals(DMNProjectClientConstants.DMNDiagramParsingErrorMessage,
-                     notificationEvent.getNotification());
-    }
-
-    @Test
-    public void testStunnerSave_ValidationUnsuccessful() {
-        final Overview overview = assertBasicStunnerSaveOperation(false);
-        assertSaveOperation(overview);
+        verify(expressionEditor, never()).setToolbarStateHandler(Mockito.<DMNProjectToolbarStateHandler>any());
+        verify(decisionNavigatorDock, never()).reload();
+        verify(decisionNavigatorDock, never()).open();
+        verify(dataTypesPage, never()).reload();
+        verify(includedModelsPage, never()).reload();
+        verify(lazyCanvasFocusUtils, never()).releaseFocus();
     }
 
     @Test
     public void testOnMultiPageEditorSelectedPageEvent() {
-
-        final SessionPresenter sessionPresenter = mock(SessionPresenter.class);
-
-        doReturn(sessionPresenter).when(diagramEditor).getSessionPresenter();
-        when(sessionPresenter.getInstance()).thenReturn(dmnEditorSession);
-        when(sessionPresenter.getView()).thenReturn(sessionPresenterView);
-        when(sessionManager.getCurrentSession()).thenReturn(dmnEditorSession);
-
-        open();
-
+        diagramEditor.open(diagram);
         diagramEditor.onMultiPageEditorSelectedPageEvent(mock(MultiPageEditorSelectedPageEvent.class));
-
         verify(searchBarComponent).disableSearch();
     }
 
-    @Test
-    public void testOnMultiPageEditorSelectedPageEventWhenEditorIsNotInTheSameSession() {
-
-        final SessionPresenter sessionPresenter = mock(SessionPresenter.class);
-
-        doReturn(sessionPresenter).when(diagramEditor).getSessionPresenter();
-        when(sessionPresenter.getInstance()).thenReturn(dmnEditorSession);
-        when(sessionPresenter.getView()).thenReturn(sessionPresenterView);
-        when(sessionManager.getCurrentSession()).thenReturn(defaultEditorSession);
-        when(defaultEditorSession.getExpressionEditor()).thenReturn(expressionEditor);
-
-        open();
-
-        diagramEditor.onMultiPageEditorSelectedPageEvent(mock(MultiPageEditorSelectedPageEvent.class));
-
-        verify(searchBarComponent, never()).disableSearch();
-    }
-
     @Test
     public void testOnRefreshFormPropertiesEvent() {
         diagramEditor.onRefreshFormPropertiesEvent(mock(RefreshFormPropertiesEvent.class));
@@ -589,23 +470,14 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
         when(documentationView.initialize(diagram)).thenReturn(documentationView);
         when(kieView.getMultiPage()).thenReturn(multiPage);
 
-        open();
+        diagramEditor.open(diagram);
 
         final InOrder inOrder = inOrder(kieView, multiPage);
         inOrder.verify(kieView).addMainEditorPage(view);
-        inOrder.verify(kieView).addPage(any(DocumentationPage.class));
+        inOrder.verify(kieView).addPage(Mockito.<DocumentationPage>any());
         inOrder.verify(multiPage).addPage(dataTypesPage);
         inOrder.verify(multiPage).addPage(includedModelsPage);
-        inOrder.verify(kieView).addOverviewPage(eq(overviewWidget), any(Command.class));
-    }
-
-    @Test
-    @Override
-    public void testLoadContentWithValidFile() {
-        super.testLoadContentWithValidFile();
-
-        verify(layoutHelper).applyLayout(eq(diagram), eq(layoutExecutor));
-        verify(feelInitializer).initializeFEELEditor();
+        inOrder.verify(kieView).addOverviewPage(eq(overviewWidget), Mockito.<com.google.gwt.user.client.Command>any());
     }
 
     @Test
@@ -615,4 +487,11 @@ public class DMNDiagramEditorTest extends AbstractProjectDiagramEditorTest {
 
         verify(feelInitializer, never()).initializeFEELEditor();
     }
+
+    @Test
+    public void testSaveEvenIfValidationNotSuccessful() {
+        assertTrue(diagramEditor.isSaveAllowedAfterValidationFailed(Violation.Type.INFO));
+        assertTrue(diagramEditor.isSaveAllowedAfterValidationFailed(Violation.Type.WARNING));
+        assertTrue(diagramEditor.isSaveAllowedAfterValidationFailed(Violation.Type.ERROR));
+    }
 }
