@@ -1,5 +1,5 @@
 /*
- * Copyright 2019 Red Hat, Inc. and/or its affiliates.
+ * Copyright 2021 Red Hat, Inc. and/or its affiliates.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,7 +17,6 @@ package org.kie.workbench.common.dmn.webapp.kogito.common.client.editor;
 
 import com.google.gwtmockito.GwtMockitoTestRunner;
 import elemental2.dom.HTMLElement;
-import org.appformer.client.context.EditorContextProvider;
 import org.jboss.errai.common.client.ui.ElementWrapperWidget;
 import org.junit.Before;
 import org.junit.Test;
@@ -25,9 +24,11 @@ import org.junit.runner.RunWith;
 import org.kie.workbench.common.dmn.api.DMNDefinitionSet;
 import org.kie.workbench.common.dmn.client.commands.general.NavigateToExpressionEditorCommand;
 import org.kie.workbench.common.dmn.client.docks.navigator.DecisionNavigatorDock;
+import org.kie.workbench.common.dmn.client.docks.navigator.common.LazyCanvasFocusUtils;
+import org.kie.workbench.common.dmn.client.editors.drd.DRDNameChanger;
 import org.kie.workbench.common.dmn.client.editors.expressions.ExpressionEditorView;
 import org.kie.workbench.common.dmn.client.editors.included.IncludedModelsPage;
-import org.kie.workbench.common.dmn.client.editors.included.imports.IncludedModelsPageStateProviderImpl;
+import org.kie.workbench.common.dmn.client.editors.included.common.IncludedModelsContext;
 import org.kie.workbench.common.dmn.client.editors.search.DMNEditorSearchIndex;
 import org.kie.workbench.common.dmn.client.editors.search.DMNSearchableElement;
 import org.kie.workbench.common.dmn.client.editors.types.DataTypePageTabActiveEvent;
@@ -37,25 +38,22 @@ import org.kie.workbench.common.dmn.client.events.EditExpressionEvent;
 import org.kie.workbench.common.dmn.client.session.DMNEditorSession;
 import org.kie.workbench.common.dmn.client.widgets.codecompletion.MonacoFEELInitializer;
 import org.kie.workbench.common.dmn.webapp.common.client.docks.preview.PreviewDiagramDock;
+import org.kie.workbench.common.dmn.webapp.kogito.common.client.session.DMNEditorSessionCommands;
 import org.kie.workbench.common.dmn.webapp.kogito.common.client.tour.GuidedTourBridgeInitializer;
 import org.kie.workbench.common.kogito.client.editor.MultiPageEditorContainerView;
-import org.kie.workbench.common.stunner.client.widgets.presenters.Viewer;
+import org.kie.workbench.common.stunner.client.widgets.editor.StunnerEditor;
+import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionDiagramPresenter;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionPresenter;
-import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionEditorPresenter;
-import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionViewerPresenter;
-import org.kie.workbench.common.stunner.core.client.ManagedInstanceStub;
+import org.kie.workbench.common.stunner.core.client.ReadOnlyProvider;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.util.CanvasFileExport;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
 import org.kie.workbench.common.stunner.core.client.components.layout.LayoutHelper;
 import org.kie.workbench.common.stunner.core.client.components.layout.OpenDiagramLayoutExecutor;
-import org.kie.workbench.common.stunner.core.client.error.DiagramClientErrorHandler;
 import org.kie.workbench.common.stunner.core.client.i18n.ClientTranslationService;
 import org.kie.workbench.common.stunner.core.client.service.ClientRuntimeError;
 import org.kie.workbench.common.stunner.core.client.service.ServiceCallback;
-import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
-import org.kie.workbench.common.stunner.core.client.session.impl.ViewerSession;
 import org.kie.workbench.common.stunner.core.command.Command;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.diagram.DiagramImpl;
@@ -63,13 +61,8 @@ import org.kie.workbench.common.stunner.core.diagram.Metadata;
 import org.kie.workbench.common.stunner.core.diagram.MetadataImpl;
 import org.kie.workbench.common.stunner.core.documentation.DocumentationView;
 import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;
-import org.kie.workbench.common.stunner.kogito.api.editor.KogitoDiagramResource;
-import org.kie.workbench.common.stunner.kogito.api.editor.impl.KogitoDiagramResourceImpl;
 import org.kie.workbench.common.stunner.kogito.client.docks.DiagramEditorPropertiesDock;
-import org.kie.workbench.common.stunner.kogito.client.editor.DiagramEditorCore;
-import org.kie.workbench.common.stunner.kogito.client.editor.event.OnDiagramFocusEvent;
 import org.kie.workbench.common.stunner.kogito.client.service.KogitoClientDiagramService;
-import org.kie.workbench.common.widgets.client.menu.FileMenuBuilder;
 import org.kie.workbench.common.widgets.client.search.component.SearchBarComponent;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
@@ -77,23 +70,19 @@ import org.mockito.Mock;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.client.mvp.PlaceManager;
 import org.uberfire.client.views.pfly.multipage.MultiPageEditorSelectedPageEvent;
-import org.uberfire.client.workbench.events.ChangeTitleWidgetEvent;
-import org.uberfire.client.workbench.widgets.common.ErrorPopupPresenter;
 import org.uberfire.client.workbench.widgets.multipage.MultiPageEditor;
-import org.uberfire.ext.editor.commons.client.menu.MenuItems;
-import org.uberfire.ext.widgets.core.client.editors.texteditor.TextEditorView;
 import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.mvp.impl.DefaultPlaceRequest;
-import org.uberfire.workbench.events.NotificationEvent;
 
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.kie.workbench.common.dmn.webapp.kogito.common.client.editor.AbstractDMNDiagramEditor.DATA_TYPES_PAGE_INDEX;
 import static org.kie.workbench.common.dmn.webapp.kogito.common.client.editor.AbstractDMNDiagramEditor.PERSPECTIVE_ID;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyBoolean;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.eq;
+import static org.mockito.Mockito.atLeastOnce;
 import static org.mockito.Mockito.doAnswer;
+import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.reset;
@@ -112,12 +101,6 @@ public abstract class AbstractDMNDiagramEditorTest {
     @Mock
     protected AbstractCanvasHandler canvasHandler;
 
-    @Mock
-    protected DiagramEditorCore.View view;
-
-    @Mock
-    protected FileMenuBuilder fileMenuBuilder;
-
     @Mock
     protected PlaceManager placeManager;
 
@@ -127,31 +110,6 @@ public abstract class AbstractDMNDiagramEditorTest {
     @Mock
     protected MultiPageEditor multiPageEditor;
 
-    @Mock
-    protected EventSourceMock<ChangeTitleWidgetEvent> changeTitleWidgetEventSourceMock;
-
-    @Mock
-    protected EventSourceMock<NotificationEvent> notificationEventSourceMock;
-
-    @Mock
-    protected EventSourceMock<OnDiagramFocusEvent> onDiagramFocusEventSourceMock;
-
-    @Mock
-    protected TextEditorView xmlEditorView;
-
-    protected ManagedInstanceStub<SessionEditorPresenter<EditorSession>> sessionEditorPresenters;
-
-    protected ManagedInstanceStub<SessionViewerPresenter<ViewerSession>> sessionViewerPresenters;
-
-    @Mock
-    protected DMNEditorMenuSessionItems dmnEditorMenuSessionItems;
-
-    @Mock
-    protected ErrorPopupPresenter errorPopupPresenter;
-
-    @Mock
-    protected DiagramClientErrorHandler diagramClientErrorHandler;
-
     @Mock
     protected ClientTranslationService clientTranslationService;
 
@@ -182,6 +140,9 @@ public abstract class AbstractDMNDiagramEditorTest {
     @Mock
     protected PreviewDiagramDock diagramPreviewDock;
 
+    @Mock
+    protected DMNEditorSessionCommands sessionCommands;
+
     @Mock
     protected LayoutHelper layoutHelper;
 
@@ -195,10 +156,16 @@ public abstract class AbstractDMNDiagramEditorTest {
     protected KogitoClientDiagramService clientDiagramService;
 
     @Mock
-    protected SessionEditorPresenter<EditorSession> editorPresenter;
+    protected StunnerEditor stunnerEditor;
 
     @Mock
-    protected SessionViewerPresenter<ViewerSession> viewerPresenter;
+    protected AbstractDMNDiagramEditor.View view;
+
+    @Mock
+    protected SessionDiagramPresenter presenter;
+
+    @Mock
+    protected SessionPresenter.View presenterView;
 
     @Mock
     protected ExpressionEditorView.Presenter expressionEditor;
@@ -249,13 +216,22 @@ public abstract class AbstractDMNDiagramEditorTest {
     protected IncludedModelsPage includedModelsPage;
 
     @Mock
-    protected IncludedModelsPageStateProviderImpl importsPageProvider;
+    protected IncludedModelsContext includedModelContext;
 
     @Mock
-    protected EditorContextProvider contextProvider;
+    protected ReadOnlyProvider readonlyProvider;
 
-    @Captor
-    protected ArgumentCaptor<KogitoDiagramResourceImpl> kogitoDiagramResourceArgumentCaptor;
+    @Mock
+    protected DRDNameChanger drdNameChanger;
+
+    @Mock
+    protected LazyCanvasFocusUtils lazyCanvasFocusUtils;
+
+    @Mock
+    private HTMLElement drdNameChangerElement;
+
+    @Mock
+    private ElementWrapperWidget drdNameWidget;
 
     @Captor
     protected ArgumentCaptor<ServiceCallback<Diagram>> serviceCallbackArgumentCaptor;
@@ -274,23 +250,25 @@ public abstract class AbstractDMNDiagramEditorTest {
         metadata = new MetadataImpl.MetadataImplBuilder(DMNDefinitionSet.class.getName()).setTitle("dmn").setRoot(root).build();
         diagram = new DiagramImpl("dmn", metadata);
 
-        sessionEditorPresenters = new ManagedInstanceStub<>(editorPresenter);
-        sessionViewerPresenters = new ManagedInstanceStub<>(viewerPresenter);
         when(searchBarComponent.getView()).thenReturn(searchBarComponentView);
         when(searchBarComponentView.getElement()).thenReturn(searchBarComponentViewElement);
         when(multiPageEditorContainerView.getMultiPage()).thenReturn(multiPageEditor);
 
-        when(editorPresenter.withToolbar(anyBoolean())).thenReturn(editorPresenter);
-        when(editorPresenter.withPalette(anyBoolean())).thenReturn(editorPresenter);
-        when(editorPresenter.displayNotifications(any())).thenReturn(editorPresenter);
         when(sessionManager.getCurrentSession()).thenReturn(session);
         when(session.getExpressionEditor()).thenReturn(expressionEditor);
 
+        when(presenter.getView()).thenReturn(presenterView);
         when(session.getCanvasHandler()).thenReturn(canvasHandler);
-        when(editorPresenter.getInstance()).thenReturn(session);
+        when(stunnerEditor.getSession()).thenReturn(session);
+        when(stunnerEditor.getPresenter()).thenReturn(presenter);
+        when(stunnerEditor.getView()).thenReturn(view);
+        when(stunnerEditor.getCanvasHandler()).thenReturn(canvasHandler);
+        when(stunnerEditor.getDiagram()).thenReturn(diagram);
         when(canvasHandler.getDiagram()).thenReturn(diagram);
         when(root.toURI()).thenReturn(ROOT);
 
+        when(drdNameChanger.getElement()).thenReturn(drdNameChangerElement);
+
         doAnswer((invocation) -> {
             final Diagram diagram = (Diagram) invocation.getArguments()[0];
             final SessionPresenter.SessionPresenterCallback callback = (SessionPresenter.SessionPresenterCallback) invocation.getArguments()[1];
@@ -299,10 +277,12 @@ public abstract class AbstractDMNDiagramEditorTest {
             callback.afterSessionOpened();
             callback.onSuccess();
             return null;
-        }).when(editorPresenter).open(any(Diagram.class),
-                                      any(SessionPresenter.SessionPresenterCallback.class));
+        }).when(stunnerEditor).open(any(Diagram.class),
+                                    any(SessionPresenter.SessionPresenterCallback.class));
 
         editor = spy(getEditor());
+
+        doReturn(drdNameWidget).when(editor).getWidget(drdNameChangerElement);
     }
 
     protected abstract AbstractDMNDiagramEditor getEditor();
@@ -310,14 +290,10 @@ public abstract class AbstractDMNDiagramEditorTest {
     @Test
     public void testOnStartup() {
         editor.onStartup(place);
-
+        verify(stunnerEditor).setReadOnly(eq(false));
         verify(decisionNavigatorDock).init(PERSPECTIVE_ID);
         verify(diagramPreviewDock).init(PERSPECTIVE_ID);
         verify(diagramPropertiesDock).init(PERSPECTIVE_ID);
-
-        verify(dmnEditorMenuSessionItems).populateMenu(fileMenuBuilder);
-        verify(fileMenuBuilder).build();
-
         verify(multiPageEditorContainerView).init(eq(editor));
         verify(guidedTourBridgeInitializer).init();
     }
@@ -325,43 +301,16 @@ public abstract class AbstractDMNDiagramEditorTest {
     @Test
     public void testOnDataTypePageNavTabActiveEvent() {
         editor.onDataTypePageNavTabActiveEvent(dataTypePageTabActiveEvent);
-
         verify(multiPageEditor).selectPage(DATA_TYPES_PAGE_INDEX);
     }
 
-    @Test
-    public void testOnDataTypeEditModeToggleEnabled() {
-        openDiagram();
-
-        when(dataTypeEditModeToggleEvent.isEditModeEnabled()).thenReturn(true);
-
-        editor.onDataTypeEditModeToggle(dataTypeEditModeToggleEvent);
-
-        verify(editor).disableMenuItem(eq(MenuItems.SAVE));
-    }
-
-    @Test
-    public void testOnDataTypeEditModeToggleDisabled() {
-        openDiagram();
-
-        when(dataTypeEditModeToggleEvent.isEditModeEnabled()).thenReturn(false);
-
-        editor.onDataTypeEditModeToggle(dataTypeEditModeToggleEvent);
-
-        verify(editor).enableMenuItem(eq(MenuItems.SAVE));
-    }
-
     @Test
     @SuppressWarnings("unchecked")
     public void testOnEditExpressionEventWhenSameSession() {
         when(editExpressionEvent.getSession()).thenReturn(session);
-
         openDiagram();
-
-        when(editorPresenter.getInstance()).thenReturn(session);
-
+        when(stunnerEditor.getSession()).thenReturn(session);
         editor.onEditExpressionEvent(editExpressionEvent);
-
         verify(searchBarComponent).disableSearch();
         verify(sessionCommandManager).execute(eq(canvasHandler),
                                               any(NavigateToExpressionEditorCommand.class));
@@ -371,7 +320,6 @@ public abstract class AbstractDMNDiagramEditorTest {
     @SuppressWarnings("unchecked")
     public void testOnEditExpressionEventWhenDifferentSession() {
         editor.onEditExpressionEvent(editExpressionEvent);
-
         verify(searchBarComponent).disableSearch();
         verify(sessionCommandManager, never()).execute(any(AbstractCanvasHandler.class),
                                                        any(Command.class));
@@ -380,73 +328,51 @@ public abstract class AbstractDMNDiagramEditorTest {
     @Test
     public void testOnMultiPageEditorSelectedPageEvent() {
         editor.onMultiPageEditorSelectedPageEvent(multiPageEditorSelectedPageEvent);
-
         verify(searchBarComponent).disableSearch();
     }
 
     @Test
     public void testOnRefreshFormPropertiesEvent() {
         editor.onRefreshFormPropertiesEvent(refreshFormPropertiesEvent);
-
         verify(searchBarComponent).disableSearch();
     }
 
     @Test
     public void testOnClose() {
         openDiagram();
-
         editor.onClose();
-
-        verify(dmnEditorMenuSessionItems, times(2)).destroy();
-        verify(editorPresenter).destroy();
-
+        verify(stunnerEditor, atLeastOnce()).close();
         verify(decisionNavigatorDock).destroy();
         verify(decisionNavigatorDock).resetContent();
-
         verify(diagramPropertiesDock).destroy();
         verify(diagramPreviewDock).destroy();
-
         verify(dataTypesPage).disableShortcuts();
     }
 
     @Test
     public void testOnFocus() {
         openDiagram();
-
         //Setting focus activates the diagram identically to opening a diagram; so reset applicable mocks.
         reset(decisionNavigatorDock, diagramPropertiesDock, diagramPreviewDock, dataTypesPage);
-
         editor.onFocus();
-
-        verify(editorPresenter).focus();
+        verify(stunnerEditor).focus();
         verify(dataTypesPage).onFocus();
         verify(dataTypesPage).enableShortcuts();
-
-        assertOnDiagramLoad();
     }
 
     @Test
     public void testOnLostFocus() {
         openDiagram();
-
         editor.onLostFocus();
-
-        verify(editorPresenter).lostFocus();
+        verify(stunnerEditor).lostFocus();
         verify(dataTypesPage).onLostFocus();
     }
 
     @Test
     public void testGetContent() {
         openDiagram();
-
         editor.getContent();
-
-        verify(clientDiagramService).transform(kogitoDiagramResourceArgumentCaptor.capture());
-
-        final KogitoDiagramResource resource = kogitoDiagramResourceArgumentCaptor.getValue();
-        assertThat(resource).isNotNull();
-        assertThat(resource.projectDiagram().isPresent()).isTrue();
-        assertThat(resource.projectDiagram().get()).isEqualTo(diagram);
+        verify(clientDiagramService).transform(eq(diagram));
     }
 
     @Test
@@ -467,15 +393,13 @@ public abstract class AbstractDMNDiagramEditorTest {
     public void testSetContentFailure() {
         final String path = "path";
         editor.setContent(path, CONTENT);
-
         verify(clientDiagramService).transform(eq(path), eq(CONTENT), serviceCallbackArgumentCaptor.capture());
-
         final ServiceCallback<Diagram> serviceCallback = serviceCallbackArgumentCaptor.getValue();
         assertThat(serviceCallback).isNotNull();
         serviceCallback.onError(clientRuntimeError);
-
         verify(feelInitializer, never()).initializeFEELEditor();
-        verify(diagramClientErrorHandler).handleError(eq(clientRuntimeError), any());
+        verify(multiPageEditorContainerView, times(1)).clear();
+        verify(multiPageEditorContainerView, times(1)).setEditorWidget(eq(view));
     }
 
     @Test
@@ -495,29 +419,25 @@ public abstract class AbstractDMNDiagramEditorTest {
         editor.onStartup(place);
 
         when(session.getCanvasHandler()).thenReturn(canvasHandler);
-        when(editorPresenter.getInstance()).thenReturn(session);
+        when(stunnerEditor.getSession()).thenReturn(session);
         when(canvasHandler.getDiagram()).thenReturn(diagram);
 
-        editor.open(diagram, mock(Viewer.Callback.class));
+        editor.open(diagram, mock(SessionPresenter.SessionPresenterCallback.class));
 
         assertOnDiagramLoad();
     }
 
     protected void assertOnDiagramLoad() {
-        verify(decisionNavigatorDock).setupCanvasHandler(canvasHandler);
+        verify(decisionNavigatorDock).reload();
         verify(layoutHelper).applyLayout(eq(diagram), eq(layoutExecutor));
         verify(feelInitializer).initializeFEELEditor();
         verify(dataTypesPage).reload();
+        verify(lazyCanvasFocusUtils, atLeastOnce()).releaseFocus();
     }
 
     @Test
-    public void testSuperOnCloseDMNOnSetContent() {
-        //First setContent call context
+    public void testReleaseOnSetContent() {
         editor.setContent("", "");
-        verify(dmnEditorMenuSessionItems, times(1)).destroy();
-
-        //Second setContent call context
-        editor.setContent("", "");
-        verify(dmnEditorMenuSessionItems, times(2)).destroy();
+        verify(stunnerEditor, times(1)).close();
     }
 }
