@@ -15,7 +15,6 @@
  */
 package org.kie.workbench.common.dmn.showcase.client.editor;
 
-import java.util.Optional;
 import java.util.function.Consumer;
 
 import javax.enterprise.context.Dependent;
@@ -23,52 +22,42 @@ import javax.enterprise.event.Event;
 import javax.enterprise.event.Observes;
 import javax.inject.Inject;
 
-import org.appformer.client.context.EditorContextProvider;
-import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.kie.workbench.common.dmn.api.qualifiers.DMNEditor;
 import org.kie.workbench.common.dmn.client.docks.navigator.DecisionNavigatorDock;
-import org.kie.workbench.common.dmn.client.editors.expressions.ExpressionEditorView;
+import org.kie.workbench.common.dmn.client.docks.navigator.common.LazyCanvasFocusUtils;
+import org.kie.workbench.common.dmn.client.editors.drd.DRDNameChanger;
 import org.kie.workbench.common.dmn.client.editors.included.IncludedModelsPage;
-import org.kie.workbench.common.dmn.client.editors.included.imports.IncludedModelsPageStateProviderImpl;
+import org.kie.workbench.common.dmn.client.editors.included.common.IncludedModelsContext;
 import org.kie.workbench.common.dmn.client.editors.search.DMNEditorSearchIndex;
 import org.kie.workbench.common.dmn.client.editors.search.DMNSearchableElement;
 import org.kie.workbench.common.dmn.client.editors.types.DataTypePageTabActiveEvent;
 import org.kie.workbench.common.dmn.client.editors.types.DataTypesPage;
 import org.kie.workbench.common.dmn.client.editors.types.listview.common.DataTypeEditModeToggleEvent;
 import org.kie.workbench.common.dmn.client.events.EditExpressionEvent;
-import org.kie.workbench.common.dmn.client.session.DMNSession;
 import org.kie.workbench.common.dmn.client.widgets.codecompletion.MonacoFEELInitializer;
 import org.kie.workbench.common.dmn.showcase.client.navigator.DMNVFSService;
 import org.kie.workbench.common.dmn.webapp.common.client.docks.preview.PreviewDiagramDock;
 import org.kie.workbench.common.dmn.webapp.kogito.common.client.editor.AbstractDMNDiagramEditor;
-import org.kie.workbench.common.dmn.webapp.kogito.common.client.editor.DMNEditorMenuSessionItems;
-import org.kie.workbench.common.dmn.webapp.kogito.common.client.editor.DMNProjectToolbarStateHandler;
 import org.kie.workbench.common.dmn.webapp.kogito.common.client.tour.GuidedTourBridgeInitializer;
 import org.kie.workbench.common.kogito.client.editor.MultiPageEditorContainerView;
-import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionEditorPresenter;
-import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionViewerPresenter;
+import org.kie.workbench.common.stunner.client.widgets.editor.StunnerEditor;
+import org.kie.workbench.common.stunner.core.client.ReadOnlyProvider;
 import org.kie.workbench.common.stunner.core.client.annotation.DiagramEditor;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.canvas.CanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.util.CanvasFileExport;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
 import org.kie.workbench.common.stunner.core.client.components.layout.LayoutHelper;
 import org.kie.workbench.common.stunner.core.client.components.layout.OpenDiagramLayoutExecutor;
-import org.kie.workbench.common.stunner.core.client.error.DiagramClientErrorHandler;
 import org.kie.workbench.common.stunner.core.client.i18n.ClientTranslationService;
 import org.kie.workbench.common.stunner.core.client.service.ClientRuntimeError;
 import org.kie.workbench.common.stunner.core.client.service.ServiceCallback;
-import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
-import org.kie.workbench.common.stunner.core.client.session.impl.ViewerSession;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.diagram.Metadata;
 import org.kie.workbench.common.stunner.core.documentation.DocumentationView;
 import org.kie.workbench.common.stunner.forms.client.event.RefreshFormPropertiesEvent;
 import org.kie.workbench.common.stunner.kogito.client.docks.DiagramEditorPropertiesDock;
-import org.kie.workbench.common.stunner.kogito.client.editor.event.OnDiagramFocusEvent;
 import org.kie.workbench.common.stunner.kogito.client.service.KogitoClientDiagramService;
-import org.kie.workbench.common.widgets.client.menu.FileMenuBuilder;
 import org.kie.workbench.common.widgets.client.search.component.SearchBarComponent;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.backend.vfs.PathFactory;
@@ -77,9 +66,6 @@ import org.uberfire.client.annotations.WorkbenchScreen;
 import org.uberfire.client.mvp.PlaceManager;
 import org.uberfire.client.promise.Promises;
 import org.uberfire.client.views.pfly.multipage.MultiPageEditorSelectedPageEvent;
-import org.uberfire.client.workbench.events.ChangeTitleWidgetEvent;
-import org.uberfire.client.workbench.widgets.common.ErrorPopupPresenter;
-import org.uberfire.ext.widgets.core.client.editors.texteditor.TextEditorView;
 import org.uberfire.lifecycle.OnStartup;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.util.URIUtil;
@@ -98,27 +84,20 @@ public class DMNDiagramEditor extends AbstractDMNDiagramEditor {
 
     private final Event<NotificationEvent> notificationEvent;
     private final DMNVFSService vfsService;
+    private final ReadOnlyProvider readOnlyProvider;
+    private final LazyCanvasFocusUtils lazyCanvasFocusUtils;
 
     @Inject
     public DMNDiagramEditor(final View view,
-                            final FileMenuBuilder fileMenuBuilder,
                             final PlaceManager placeManager,
-                            final MultiPageEditorContainerView multiPageEditorContainerView,
-                            final Event<ChangeTitleWidgetEvent> changeTitleNotificationEvent,
-                            final Event<NotificationEvent> notificationEvent,
-                            final Event<OnDiagramFocusEvent> onDiagramFocusEvent,
-                            final TextEditorView xmlEditorView,
-                            final ManagedInstance<SessionEditorPresenter<EditorSession>> editorSessionPresenterInstances,
-                            final ManagedInstance<SessionViewerPresenter<ViewerSession>> viewerSessionPresenterInstances,
-                            final DMNEditorMenuSessionItems menuSessionItems,
-                            final ErrorPopupPresenter errorPopupPresenter,
-                            final DiagramClientErrorHandler diagramClientErrorHandler,
-                            final ClientTranslationService translationService,
-                            final @DMNEditor DocumentationView<Diagram> documentationView,
+                            final MultiPageEditorContainerView containerView,
+                            final StunnerEditor stunnerEditor,
                             final DMNEditorSearchIndex editorSearchIndex,
                             final SearchBarComponent<DMNSearchableElement> searchBarComponent,
                             final SessionManager sessionManager,
                             final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
+                            final @DMNEditor DocumentationView documentationView,
+                            final ClientTranslationService translationService,
                             final Event<RefreshFormPropertiesEvent> refreshFormPropertiesEvent,
                             final DecisionNavigatorDock decisionNavigatorDock,
                             final DiagramEditorPropertiesDock diagramPropertiesDock,
@@ -127,33 +106,27 @@ public class DMNDiagramEditor extends AbstractDMNDiagramEditor {
                             final OpenDiagramLayoutExecutor openDiagramLayoutExecutor,
                             final DataTypesPage dataTypesPage,
                             final KogitoClientDiagramService diagramServices,
-                            final DMNVFSService vfsService,
-                            final Promises promises,
                             final MonacoFEELInitializer feelInitializer,
                             final CanvasFileExport canvasFileExport,
+                            final Promises promises,
                             final IncludedModelsPage includedModelsPage,
-                            final IncludedModelsPageStateProviderImpl importsPageProvider,
-                            final EditorContextProvider contextProvider,
-                            final GuidedTourBridgeInitializer guidedTourBridgeInitializer) {
+                            final IncludedModelsContext includedModelContext,
+                            final GuidedTourBridgeInitializer guidedTourBridgeInitializer,
+                            final DRDNameChanger drdNameChanger,
+                            final Event<NotificationEvent> notificationEvent,
+                            final DMNVFSService vfsService,
+                            final ReadOnlyProvider readOnlyProvider,
+                            final LazyCanvasFocusUtils lazyCanvasFocusUtils) {
         super(view,
-              fileMenuBuilder,
               placeManager,
-              multiPageEditorContainerView,
-              changeTitleNotificationEvent,
-              notificationEvent,
-              onDiagramFocusEvent,
-              xmlEditorView,
-              editorSessionPresenterInstances,
-              viewerSessionPresenterInstances,
-              menuSessionItems,
-              errorPopupPresenter,
-              diagramClientErrorHandler,
-              translationService,
-              documentationView,
+              containerView,
+              stunnerEditor,
               editorSearchIndex,
               searchBarComponent,
               sessionManager,
               sessionCommandManager,
+              documentationView,
+              translationService,
               refreshFormPropertiesEvent,
               decisionNavigatorDock,
               diagramPropertiesDock,
@@ -166,11 +139,13 @@ public class DMNDiagramEditor extends AbstractDMNDiagramEditor {
               canvasFileExport,
               promises,
               includedModelsPage,
-              importsPageProvider,
-              contextProvider,
-              guidedTourBridgeInitializer);
+              includedModelContext,
+              guidedTourBridgeInitializer,
+              drdNameChanger);
         this.notificationEvent = notificationEvent;
         this.vfsService = vfsService;
+        this.readOnlyProvider = readOnlyProvider;
+        this.lazyCanvasFocusUtils = lazyCanvasFocusUtils;
     }
 
     @Override
@@ -178,18 +153,9 @@ public class DMNDiagramEditor extends AbstractDMNDiagramEditor {
     @SuppressWarnings("unused")
     public void onStartup(final PlaceRequest place) {
         super.onStartup(place);
-
-        setContent("", place.getParameter(CONTENT_PARAMETER_NAME, ""));
-    }
-
-    @Override
-    protected void makeMenuBar() {
-        if (!menuBarInitialized) {
-            getFileMenuBuilder().addSave(this::doSave);
-            getMenuSessionItems().populateMenu(getFileMenuBuilder());
-            makeAdditionalStunnerMenus(getFileMenuBuilder());
-            menuBarInitialized = true;
-        }
+        final String path = getPlaceRequest().getParameter(DMNDiagramEditor.FILE_NAME_PARAMETER_NAME, "");
+        final String value = place.getParameter(CONTENT_PARAMETER_NAME, "");
+        setContent(path, value);
     }
 
     @Override
@@ -209,18 +175,12 @@ public class DMNDiagramEditor extends AbstractDMNDiagramEditor {
 
     @Override
     public void onDiagramLoad() {
-        final Optional<CanvasHandler> canvasHandler = Optional.ofNullable(getCanvasHandler());
-
-        canvasHandler.ifPresent(c -> {
-            final Metadata metadata = c.getDiagram().getMetadata();
-            metadata.setPath(makeMetadataPath(metadata));
-
-            final ExpressionEditorView.Presenter expressionEditor = ((DMNSession) sessionManager.getCurrentSession()).getExpressionEditor();
-            expressionEditor.setToolbarStateHandler(new DMNProjectToolbarStateHandler(getMenuSessionItems()));
-            decisionNavigatorDock.setupCanvasHandler(c);
-            dataTypesPage.reload();
-            includedModelsPage.setup(importsPageProvider.withDiagram(c.getDiagram()));
-        });
+        final Metadata metadata = stunnerEditor.getCanvasHandler().getDiagram().getMetadata();
+        metadata.setPath(makeMetadataPath(metadata));
+        decisionNavigatorDock.reload();
+        dataTypesPage.reload();
+        includedModelsPage.reload();
+        lazyCanvasFocusUtils.releaseFocus();
     }
 
     private Path makeMetadataPath(final Metadata metadata) {
@@ -231,8 +191,8 @@ public class DMNDiagramEditor extends AbstractDMNDiagramEditor {
     }
 
     @SuppressWarnings("unchecked")
-    private void doSave() {
-        final Path path = getCanvasHandler().getDiagram().getMetadata().getPath();
+    void doSave() {
+        final Path path = stunnerEditor.getDiagram().getMetadata().getPath();
 
         getContent().then(xml -> {
             vfsService.saveFile(path,
@@ -242,12 +202,12 @@ public class DMNDiagramEditor extends AbstractDMNDiagramEditor {
                                     public void onSuccess(final String xml) {
                                         resetContentHash();
                                         notificationEvent.fire(new NotificationEvent(INSTANCE.ItemSavedSuccessfully()));
-                                        hideLoadingViews();
+                                        getBaseEditorView().hideBusyIndicator();
                                     }
 
                                     @Override
                                     public void onError(final ClientRuntimeError error) {
-                                        onSaveError(error);
+                                        stunnerEditor.handleError(error);
                                     }
                                 });
             return promises.resolve();
@@ -278,4 +238,9 @@ public class DMNDiagramEditor extends AbstractDMNDiagramEditor {
     public void onRefreshFormPropertiesEvent(final @Observes RefreshFormPropertiesEvent event) {
         super.onRefreshFormPropertiesEvent(event);
     }
+
+    @Override
+    public boolean isReadOnly() {
+        return readOnlyProvider.isReadOnlyDiagram();
+    }
 }
