@@ -23,16 +23,17 @@ import org.kie.workbench.common.stunner.core.client.shape.MutationContext;
 import org.kie.workbench.common.stunner.core.command.CommandResult;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
 import static org.junit.Assert.assertNotEquals;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class AddCanvasDockedNodeCommandTest extends AbstractCanvasCommandTest {
 
     @Mock
@@ -45,6 +46,7 @@ public class AddCanvasDockedNodeCommandTest extends AbstractCanvasCommandTest {
     @Before
     public void setUp() throws Exception {
         super.setUp();
+        when(canvasHandler.dock(parent, candidate)).thenReturn(true);
         this.tested = new AddCanvasDockedNodeCommand(parent,
                                                      candidate,
                                                      SHAPE_SET_ID);
