@@ -16,6 +16,8 @@
 
 package org.kie.workbench.common.stunner.project.backend.service;
 
+import java.util.Optional;
+
 import javax.annotation.PostConstruct;
 import javax.enterprise.context.ApplicationScoped;
 import javax.enterprise.event.Event;
@@ -28,7 +30,9 @@ import org.guvnor.common.services.project.model.Package;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.jboss.errai.bus.server.annotations.Service;
+import org.jboss.errai.security.shared.api.identity.User;
 import org.kie.workbench.common.services.backend.service.KieService;
+import org.kie.workbench.common.services.backend.service.KieServiceOverviewLoader;
 import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.kie.workbench.common.stunner.core.api.DefinitionManager;
 import org.kie.workbench.common.stunner.core.api.FactoryManager;
@@ -49,8 +53,7 @@ import org.uberfire.workbench.events.ResourceOpenedEvent;
 public class ProjectDiagramServiceImpl extends KieService<ProjectDiagram>
         implements ProjectDiagramService {
 
-    private static final Logger LOG =
-            LoggerFactory.getLogger(ProjectDiagramServiceImpl.class.getName());
+    private static final Logger LOG = LoggerFactory.getLogger(ProjectDiagramServiceImpl.class.getName());
 
     private final SessionInfo sessionInfo;
     private final Event<ResourceOpenedEvent> resourceOpenedEvent;
@@ -66,6 +69,8 @@ public class ProjectDiagramServiceImpl extends KieService<ProjectDiagram>
              null,
              null,
              null,
+             null,
+             null,
              null);
     }
 
@@ -78,7 +83,9 @@ public class ProjectDiagramServiceImpl extends KieService<ProjectDiagram>
                                      final SessionInfo sessionInfo,
                                      final Event<ResourceOpenedEvent> resourceOpenedEvent,
                                      final CommentedOptionFactory commentedOptionFactory,
-                                     final KieModuleService moduleService) {
+                                     final KieModuleService moduleService,
+                                     final KieServiceOverviewLoader overviewLoader,
+                                     final User identity) {
         this.ioService = ioService;
         this.sessionInfo = sessionInfo;
         this.resourceOpenedEvent = resourceOpenedEvent;
@@ -88,7 +95,9 @@ public class ProjectDiagramServiceImpl extends KieService<ProjectDiagram>
                                           definitionSetServiceInstances,
                                           registryFactory,
                                           ioService,
-                                          moduleService);
+                                          moduleService,
+                                          overviewLoader,
+                                          identity);
     }
 
     @PostConstruct
@@ -107,16 +116,19 @@ public class ProjectDiagramServiceImpl extends KieService<ProjectDiagram>
         return controller.accepts(path);
     }
 
+    @Override
     public Path create(final Path path,
                        final String name,
                        final String defSetId,
-                       final String projName,
-                       final Package projPkg) {
+                       final String projectName,
+                       final Package projectPkg,
+                       final Optional<String> projectType) {
         return controller.create(path,
                                  name,
                                  defSetId,
-                                 projName,
-                                 projPkg);
+                                 projectName,
+                                 projectPkg,
+                                 projectType);
     }
 
     @Override
@@ -154,11 +166,30 @@ public class ProjectDiagramServiceImpl extends KieService<ProjectDiagram>
                                commentedOptionFactory.makeCommentedOption(comment));
     }
 
+    @Override
+    public Path saveAsXml(final Path path,
+                          final String xml,
+                          final Metadata metadata,
+                          final String comment) {
+        LOG.debug("Saving diagram as XML into path [" + path + "].");
+        return controller.saveAsXml(path,
+                                    xml,
+                                    metadataService.setUpAttributes(path,
+                                                                    metadata),
+                                    commentedOptionFactory.makeCommentedOption(comment));
+    }
+
     @Override
     public ProjectMetadata saveOrUpdate(final ProjectDiagram diagram) {
         return controller.saveOrUpdate(diagram);
     }
 
+    @Override
+    public Path saveOrUpdateSvg(final Path diagramPath,
+                                final String rawDiagramSvg) {
+        return controller.saveOrUpdateSvg(diagramPath, rawDiagramSvg);
+    }
+
     @Override
     public boolean delete(final ProjectDiagram diagram) {
         return controller.delete(diagram);
@@ -172,7 +203,7 @@ public class ProjectDiagramServiceImpl extends KieService<ProjectDiagram>
     }
 
     @Override
-    public String getRawContent(ProjectDiagram diagram) {
+    public String getRawContent(final ProjectDiagram diagram) {
         return controller.getRawContent(diagram);
     }
 
@@ -181,12 +212,16 @@ public class ProjectDiagramServiceImpl extends KieService<ProjectDiagram>
                                                               final Instance<DefinitionSetService> definitionSetServiceInstances,
                                                               final BackendRegistryFactory registryFactory,
                                                               final IOService ioService,
-                                                              final KieModuleService moduleService) {
+                                                              final KieModuleService moduleService,
+                                                              final KieServiceOverviewLoader overviewLoader,
+                                                              final User identity) {
         return new ProjectDiagramServiceController(definitionManager,
                                                    factoryManager,
                                                    definitionSetServiceInstances,
                                                    ioService,
                                                    registryFactory,
-                                                   moduleService);
+                                                   moduleService,
+                                                   overviewLoader,
+                                                   identity);
     }
 }
