@@ -21,9 +21,9 @@ import java.util.Objects;
 import javax.validation.Valid;
 
 import org.jboss.errai.common.client.api.annotations.MapsTo;
-import org.jboss.errai.common.client.api.annotations.NonPortable;
 import org.jboss.errai.common.client.api.annotations.Portable;
 import org.jboss.errai.databinding.client.api.Bindable;
+import org.kie.workbench.common.forms.adf.definitions.annotations.FieldParam;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormDefinition;
 import org.kie.workbench.common.forms.adf.definitions.annotations.FormField;
 import org.kie.workbench.common.forms.adf.definitions.settings.FieldPolicy;
@@ -35,33 +35,36 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.event.message.C
 import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
 import org.kie.workbench.common.stunner.core.definition.annotation.Definition;
-import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
+import org.kie.workbench.common.stunner.core.definition.annotation.Property;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.Morph;
-import org.kie.workbench.common.stunner.core.definition.builder.Builder;
-import org.kie.workbench.common.stunner.core.factory.graph.NodeFactory;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
 
+import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.processing.fields.fieldInitializers.nestedForms.SubFormFieldInitializer.COLLAPSIBLE_CONTAINER;
+import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.processing.fields.fieldInitializers.nestedForms.SubFormFieldInitializer.FIELD_CONTAINER_PARAM;
+
 @Portable
 @Bindable
-@Definition(graphFactory = NodeFactory.class, builder = IntermediateMessageEventCatching.IntermediateMessageEventCatchingBuilder.class)
+@Definition
 @Morph(base = BaseCatchingIntermediateEvent.class)
 @FormDefinition(
         startElement = "general",
-        policy = FieldPolicy.ONLY_MARKED
+        policy = FieldPolicy.ONLY_MARKED,
+        defaultFieldSettings = {@FieldParam(name = FIELD_CONTAINER_PARAM, value = COLLAPSIBLE_CONTAINER)}
 )
 public class IntermediateMessageEventCatching extends BaseCatchingIntermediateEvent {
 
-    @PropertySet
+    @Property
     @FormField(afterElement = "general")
     @Valid
     protected CancellingMessageEventExecutionSet executionSet;
 
-    @PropertySet
-    @FormField(afterElement = "executionSet")
-    @Valid
-    protected DataIOSet dataIOSet;
-
     public IntermediateMessageEventCatching() {
+        this(new BPMNGeneralSet(""),
+             new BackgroundSet(),
+             new FontSet(),
+             new CircleDimensionSet(new Radius()),
+             new DataIOSet(),
+             new CancellingMessageEventExecutionSet());
     }
 
     public IntermediateMessageEventCatching(final @MapsTo("general") BPMNGeneralSet general,
@@ -73,8 +76,8 @@ public class IntermediateMessageEventCatching extends BaseCatchingIntermediateEv
         super(general,
               backgroundSet,
               fontSet,
-              dimensionsSet);
-        this.dataIOSet = dataIOSet;
+              dimensionsSet,
+              dataIOSet);
         this.executionSet = executionSet;
     }
 
@@ -86,36 +89,17 @@ public class IntermediateMessageEventCatching extends BaseCatchingIntermediateEv
         this.executionSet = executionSet;
     }
 
-    public DataIOSet getDataIOSet() {
-        return dataIOSet;
-    }
-
-    public void setDataIOSet(DataIOSet dataIOSet) {
-        this.dataIOSet = dataIOSet;
-    }
-
-    @Override
-    public boolean hasOutputVars() {
-        return true;
-    }
-
-    @Override
-    public boolean isSingleOutputVar() {
-        return true;
-    }
-
     @Override
     protected void initLabels() {
         super.initLabels();
         labels.add("messageflow_end");
+        labels.add("FromEventbasedGateway");
     }
 
     @Override
     public int hashCode() {
         return HashUtil.combineHashCodes(super.hashCode(),
-                                         executionSet.hashCode(),
-                                         dataIOSet.hashCode(),
-                                         labels.hashCode());
+                                         executionSet.hashCode());
     }
 
     @Override
@@ -123,24 +107,8 @@ public class IntermediateMessageEventCatching extends BaseCatchingIntermediateEv
         if (o instanceof IntermediateMessageEventCatching) {
             IntermediateMessageEventCatching other = (IntermediateMessageEventCatching) o;
             return super.equals(other) &&
-                    Objects.equals(executionSet, other.executionSet) &&
-                    Objects.equals(dataIOSet, other.dataIOSet) &&
-                    Objects.equals(labels, other.labels);
+                    Objects.equals(executionSet, other.executionSet);
         }
         return false;
     }
-
-    @NonPortable
-    public static class IntermediateMessageEventCatchingBuilder implements Builder<IntermediateMessageEventCatching> {
-
-        @Override
-        public IntermediateMessageEventCatching build() {
-            return new IntermediateMessageEventCatching(new BPMNGeneralSet(""),
-                                                        new BackgroundSet(),
-                                                        new FontSet(),
-                                                        new CircleDimensionSet(new Radius()),
-                                                        new DataIOSet(),
-                                                        new CancellingMessageEventExecutionSet());
-        }
-    }
 }
\ No newline at end of file
