@@ -39,7 +39,7 @@ public class DiagramSetTest {
 
     private static final String NAME_VALID = "My New Name";
     private static final String NAME_INVALID = "";
-    private static final String ID_VALID = "My New Id";
+    private static final String ID_VALID = "My_New_Id";
     private static final String ID_INVALID = "";
     private static final String PACKAGE_VALID = "My New Package";
     private static final String PACKAGE_INVALID = "";
@@ -58,6 +58,7 @@ public class DiagramSetTest {
         tested.setId(new Id(ID_VALID));
         tested.setPackageProperty(new Package(PACKAGE_VALID));
         tested.setVersion(new Version(VERSION_VALID));
+        tested.setProcessType(new ProcessType());
     }
 
     @Test
@@ -94,6 +95,14 @@ public class DiagramSetTest {
         assertEquals(1, violations.size());
     }
 
+    @Test
+    public void testProcessType() {
+        ProcessType test = new ProcessType();
+        test.setValue("Private");
+        tested.setProcessType(test);
+        assertEquals("Private", tested.getProcessType().getValue());
+    }
+
     @Test
     public void testGetImports() {
         DiagramSet diagramSet = new DiagramSet();
