@@ -25,6 +25,7 @@ import org.kie.workbench.common.stunner.bpmn.definition.IntermediateCompensation
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateConditionalEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateErrorEventCatching;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateEscalationEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateLinkEventCatching;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateMessageEventCatching;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateSignalEventCatching;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateTimerEvent;
@@ -32,6 +33,7 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.event.BaseCance
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.conditional.CancellingConditionalEventExecutionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.error.CancellingErrorEventExecutionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.escalation.CancellingEscalationEventExecutionSet;
+import org.kie.workbench.common.stunner.bpmn.definition.property.event.link.LinkEventExecutionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.message.CancellingMessageEventExecutionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.signal.CancellingSignalEventExecutionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.event.timer.CancellingTimerEventExecutionSet;
@@ -44,7 +46,7 @@ import static org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunn
 
 public class IntermediateCatchEventConverter {
 
-    private final PropertyWriterFactory propertyWriterFactory;
+    protected final PropertyWriterFactory propertyWriterFactory;
 
     public IntermediateCatchEventConverter(PropertyWriterFactory propertyWriterFactory) {
         this.propertyWriterFactory = propertyWriterFactory;
@@ -54,17 +56,20 @@ public class IntermediateCatchEventConverter {
         return NodeMatch.fromNode(BaseCatchingIntermediateEvent.class, PropertyWriter.class)
                 .when(IntermediateMessageEventCatching.class, this::messageEvent)
                 .when(IntermediateSignalEventCatching.class, this::signalEvent)
+                .when(IntermediateLinkEventCatching.class, this::linkEvent)
                 .when(IntermediateErrorEventCatching.class, this::errorEvent)
                 .when(IntermediateTimerEvent.class, this::timerEvent)
                 .when(IntermediateConditionalEvent.class, this::conditionalEvent)
                 .when(IntermediateEscalationEvent.class, this::escalationEvent)
                 .when(IntermediateCompensationEvent.class, this::compensationEvent)
 
-                .apply(node).value();
+                .apply(node)
+                .value();
     }
 
-    private PropertyWriter errorEvent(Node<View<IntermediateErrorEventCatching>, ?> n) {
+    protected PropertyWriter errorEvent(Node<View<IntermediateErrorEventCatching>, ?> n) {
         CatchEventPropertyWriter p = createCatchEventPropertyWriter(n);
+        p.setAbsoluteBounds(n);
         p.getFlowElement().setId(n.getUUID());
 
         IntermediateErrorEventCatching definition = n.getContent().getDefinition();
@@ -78,16 +83,14 @@ public class IntermediateCatchEventConverter {
         CancellingErrorEventExecutionSet executionSet = definition.getExecutionSet();
         p.setCancelActivity(executionSet.getCancelActivity().getValue());
         p.addSlaDueDate(executionSet.getSlaDueDate());
-
-        p.setAbsoluteBounds(n);
-
         p.addError(executionSet.getErrorRef());
 
         return p;
     }
 
-    private PropertyWriter signalEvent(Node<View<IntermediateSignalEventCatching>, ?> n) {
+    protected PropertyWriter signalEvent(Node<View<IntermediateSignalEventCatching>, ?> n) {
         CatchEventPropertyWriter p = createCatchEventPropertyWriter(n);
+        p.setAbsoluteBounds(n);
         p.getFlowElement().setId(n.getUUID());
 
         IntermediateSignalEventCatching definition = n.getContent().getDefinition();
@@ -96,22 +99,39 @@ public class IntermediateCatchEventConverter {
         p.setName(general.getName().getValue());
         p.setDocumentation(general.getDocumentation().getValue());
 
-        p.setAssignmentsInfo(
-                definition.getDataIOSet().getAssignmentsinfo());
+        p.setAssignmentsInfo(definition.getDataIOSet().getAssignmentsinfo());
 
         CancellingSignalEventExecutionSet executionSet = definition.getExecutionSet();
         p.setCancelActivity(executionSet.getCancelActivity().getValue());
         p.addSlaDueDate(executionSet.getSlaDueDate());
-
-        p.setAbsoluteBounds(n);
-
         p.addSignal(definition.getExecutionSet().getSignalRef());
 
+
         return p;
     }
 
-    private PropertyWriter timerEvent(Node<View<IntermediateTimerEvent>, ?> n) {
+    protected PropertyWriter linkEvent(Node<View<IntermediateLinkEventCatching>, ?> n) {
         CatchEventPropertyWriter p = createCatchEventPropertyWriter(n);
+        p.setAbsoluteBounds(n);
+        p.getFlowElement().setId(n.getUUID());
+
+        IntermediateLinkEventCatching definition = n.getContent().getDefinition();
+
+        BPMNGeneralSet general = definition.getGeneral();
+        p.setName(general.getName().getValue());
+        p.setDocumentation(general.getDocumentation().getValue());
+
+        p.setAssignmentsInfo(definition.getDataIOSet().getAssignmentsinfo());
+
+        LinkEventExecutionSet executionSet = definition.getExecutionSet();
+        p.addLink(executionSet.getLinkRef());
+
+        return p;
+    }
+
+    protected PropertyWriter timerEvent(Node<View<IntermediateTimerEvent>, ?> n) {
+        CatchEventPropertyWriter p = createCatchEventPropertyWriter(n);
+        p.setAbsoluteBounds(n);
         p.getFlowElement().setId(n.getUUID());
 
         IntermediateTimerEvent definition = n.getContent().getDefinition();
@@ -120,19 +140,19 @@ public class IntermediateCatchEventConverter {
         p.setName(general.getName().getValue());
         p.setDocumentation(general.getDocumentation().getValue());
 
+        p.setAssignmentsInfo(definition.getDataIOSet().getAssignmentsinfo());
+
         CancellingTimerEventExecutionSet executionSet = definition.getExecutionSet();
         p.setCancelActivity(executionSet.getCancelActivity().getValue());
         p.addSlaDueDate(executionSet.getSlaDueDate());
-
-        p.setAbsoluteBounds(n);
-
         p.addTimer(executionSet.getTimerSettings());
 
         return p;
     }
 
-    private PropertyWriter messageEvent(Node<View<IntermediateMessageEventCatching>, ?> n) {
+    protected PropertyWriter messageEvent(Node<View<IntermediateMessageEventCatching>, ?> n) {
         CatchEventPropertyWriter p = createCatchEventPropertyWriter(n);
+        p.setAbsoluteBounds(n);
         p.getFlowElement().setId(n.getUUID());
 
         IntermediateMessageEventCatching definition = n.getContent().getDefinition();
@@ -146,16 +166,14 @@ public class IntermediateCatchEventConverter {
         CancellingMessageEventExecutionSet executionSet = definition.getExecutionSet();
         p.setCancelActivity(executionSet.getCancelActivity().getValue());
         p.addSlaDueDate(executionSet.getSlaDueDate());
-
-        p.setAbsoluteBounds(n);
-
         p.addMessage(executionSet.getMessageRef());
 
         return p;
     }
 
-    private PropertyWriter conditionalEvent(Node<View<IntermediateConditionalEvent>, ?> n) {
+    protected PropertyWriter conditionalEvent(Node<View<IntermediateConditionalEvent>, ?> n) {
         CatchEventPropertyWriter p = createCatchEventPropertyWriter(n);
+        p.setAbsoluteBounds(n);
         p.getFlowElement().setId(n.getUUID());
 
         IntermediateConditionalEvent definition = n.getContent().getDefinition();
@@ -164,18 +182,19 @@ public class IntermediateCatchEventConverter {
         p.setName(general.getName().getValue());
         p.setDocumentation(general.getDocumentation().getValue());
 
+        p.setAssignmentsInfo(definition.getDataIOSet().getAssignmentsinfo());
+
         CancellingConditionalEventExecutionSet executionSet = definition.getExecutionSet();
         p.setCancelActivity(executionSet.getCancelActivity().getValue());
         p.addSlaDueDate(executionSet.getSlaDueDate());
-
-        p.setAbsoluteBounds(n);
-
         p.addCondition(executionSet.getConditionExpression());
+
         return p;
     }
 
-    private PropertyWriter escalationEvent(Node<View<IntermediateEscalationEvent>, ?> n) {
+    protected PropertyWriter escalationEvent(Node<View<IntermediateEscalationEvent>, ?> n) {
         CatchEventPropertyWriter p = createCatchEventPropertyWriter(n);
+        p.setAbsoluteBounds(n);
         p.getFlowElement().setId(n.getUUID());
 
         IntermediateEscalationEvent definition = n.getContent().getDefinition();
@@ -184,21 +203,19 @@ public class IntermediateCatchEventConverter {
         p.setName(general.getName().getValue());
         p.setDocumentation(general.getDocumentation().getValue());
 
-        p.setAssignmentsInfo(
-                definition.getDataIOSet().getAssignmentsinfo());
+        p.setAssignmentsInfo(definition.getDataIOSet().getAssignmentsinfo());
 
         CancellingEscalationEventExecutionSet executionSet = definition.getExecutionSet();
         p.setCancelActivity(executionSet.getCancelActivity().getValue());
         p.addSlaDueDate(executionSet.getSlaDueDate());
-
-        p.setAbsoluteBounds(n);
-
         p.addEscalation(executionSet.getEscalationRef());
+
         return p;
     }
 
-    private PropertyWriter compensationEvent(Node<View<IntermediateCompensationEvent>, ?> n) {
+    protected PropertyWriter compensationEvent(Node<View<IntermediateCompensationEvent>, ?> n) {
         CatchEventPropertyWriter p = createCatchEventPropertyWriter(n);
+        p.setAbsoluteBounds(n);
         p.getFlowElement().setId(n.getUUID());
 
         IntermediateCompensationEvent definition = n.getContent().getDefinition();
@@ -207,16 +224,16 @@ public class IntermediateCatchEventConverter {
         p.setName(general.getName().getValue());
         p.setDocumentation(general.getDocumentation().getValue());
 
+        p.setAssignmentsInfo(definition.getDataIOSet().getAssignmentsinfo());
+
         BaseCancellingEventExecutionSet executionSet = definition.getExecutionSet();
         p.addSlaDueDate(executionSet.getSlaDueDate());
-        p.setAbsoluteBounds(n);
-
         p.addCompensation();
 
         return p;
     }
 
-    private CatchEventPropertyWriter createCatchEventPropertyWriter(Node<? extends View, ?> n) {
+    protected CatchEventPropertyWriter createCatchEventPropertyWriter(Node<? extends View, ?> n) {
         return getDockSourceNode(n).isPresent() ?
                 propertyWriterFactory.of(bpmn2.createBoundaryEvent()) :
                 propertyWriterFactory.of(bpmn2.createIntermediateCatchEvent());
