@@ -41,7 +41,7 @@ import org.kie.workbench.common.stunner.bpmn.definition.BusinessRuleTask;
 import org.kie.workbench.common.stunner.bpmn.definition.GenericServiceTask;
 import org.kie.workbench.common.stunner.bpmn.definition.NoneTask;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.BaseUserTaskExecutionSet;
-import org.kie.workbench.common.stunner.bpmn.workitem.ServiceTask;
+import org.kie.workbench.common.stunner.bpmn.workitem.CustomTask;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
@@ -50,8 +50,8 @@ import org.mockito.Mock;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotEquals;
-import static org.mockito.Matchers.anyString;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.when;
@@ -81,10 +81,10 @@ public abstract class BaseTaskConverterTest {
     private Node<View<NoneTask>, Edge> noneTaskNode;
 
     @Mock
-    private Node<View<org.kie.workbench.common.stunner.bpmn.workitem.ServiceTask>, Edge> serviceTaskNode;
+    private Node<View<CustomTask>, Edge> serviceTaskNode;
 
     @Mock
-    private View<org.kie.workbench.common.stunner.bpmn.workitem.ServiceTask> serviceTaskContent;
+    private View<CustomTask> serviceTaskContent;
 
     @Mock
     protected View<GenericServiceTask> genericServiceTaskContent;
@@ -105,7 +105,7 @@ public abstract class BaseTaskConverterTest {
     public void setUp() {
         noneTaskDefinition = new NoneTask();
 
-        when(factoryManager.newNode(anyString(), eq(NoneTask.class))).thenReturn(noneTaskNode);
+        when(factoryManager.newNode(any(), eq(NoneTask.class))).thenReturn(noneTaskNode);
         when(noneTaskNode.getContent()).thenReturn(noneTaskContent);
         when(noneTaskContent.getDefinition()).thenReturn(noneTaskDefinition);
         when(entry.getEStructuralFeature()).thenReturn(mock(EStructuralFeature.class));
@@ -134,7 +134,7 @@ public abstract class BaseTaskConverterTest {
         BusinessRuleTaskPropertyReader propertyReader = mock(BusinessRuleTaskPropertyReader.class);
         BusinessRuleTask businessRuleDefinition = new BusinessRuleTask();
 
-        when(factoryManager.newNode(anyString(), eq(BusinessRuleTask.class))).thenReturn(businessRuleTaskNode);
+        when(factoryManager.newNode(any(), eq(BusinessRuleTask.class))).thenReturn(businessRuleTaskNode);
         when(businessRuleTaskNode.getContent()).thenReturn(businessRuleTaskContent);
         when(businessRuleTaskContent.getDefinition()).thenReturn(businessRuleDefinition);
         when(propertyReaderFactory.of(task)).thenReturn(propertyReader);
@@ -148,12 +148,12 @@ public abstract class BaseTaskConverterTest {
     public void convertServiceTask() {
         org.eclipse.bpmn2.ServiceTask task = mock(org.eclipse.bpmn2.ServiceTask.class);
         ServiceTaskPropertyReader serviceTaskPropertyReader = mock(ServiceTaskPropertyReader.class);
-        ServiceTask definition = new ServiceTask();
+        CustomTask definition = new CustomTask();
         FeatureMap attributes = mock(FeatureMap.class);
         FeatureMap.Entry ruleAttr = mock(FeatureMap.Entry.class);
         EStructuralFeature ruleFeature = mock(EStructuralFeature.class);
 
-        when(factoryManager.newNode(anyString(), eq(ServiceTask.class))).thenReturn(serviceTaskNode);
+        when(factoryManager.newNode(any(), eq(CustomTask.class))).thenReturn(serviceTaskNode);
         when(serviceTaskNode.getContent()).thenReturn(serviceTaskContent);
         when(serviceTaskContent.getDefinition()).thenReturn(definition);
         when(propertyReaderFactory.ofCustom(task)).thenReturn(Optional.of(serviceTaskPropertyReader));
@@ -179,7 +179,7 @@ public abstract class BaseTaskConverterTest {
         FeatureMap.Entry ruleAttr = mock(FeatureMap.Entry.class);
         EStructuralFeature ruleFeature = mock(EStructuralFeature.class);
 
-        when(factoryManager.newNode(anyString(), eq(GenericServiceTask.class))).thenReturn(genericServiceTaskNode);
+        when(factoryManager.newNode(any(), eq(GenericServiceTask.class))).thenReturn(genericServiceTaskNode);
         when(genericServiceTaskNode.getContent()).thenReturn(genericServiceTaskContent);
         when(genericServiceTaskContent.getDefinition()).thenReturn(definition);
         when(propertyReaderFactory.of(task)).thenReturn(genericServiceTaskPropertyReader);
