@@ -40,7 +40,6 @@ import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.command.GraphCommandManager;
 import org.kie.workbench.common.stunner.core.graph.command.impl.AddNodeCommand;
 import org.kie.workbench.common.stunner.core.graph.command.impl.GraphCommandFactory;
-import org.kie.workbench.common.stunner.core.graph.command.impl.UpdateElementPropertyValueCommand;
 import org.kie.workbench.common.stunner.core.graph.content.definition.Definition;
 import org.kie.workbench.common.stunner.core.graph.processing.index.GraphIndexBuilder;
 import org.kie.workbench.common.stunner.core.graph.processing.index.Index;
@@ -49,18 +48,18 @@ import org.kie.workbench.common.stunner.core.rule.RuleManager;
 import org.kie.workbench.common.stunner.core.util.UUID;
 import org.kie.workbench.common.stunner.project.diagram.ProjectMetadata;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
 import static org.junit.Assert.assertEquals;
 import static org.kie.workbench.common.stunner.core.definition.adapter.binding.BindableAdapterUtils.getDefinitionId;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyString;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyString;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class CaseGraphFactoryImplTest {
 
     public static final String MILESTONE = "Milestone";
@@ -166,16 +165,11 @@ public class CaseGraphFactoryImplTest {
     }
 
     @Test
+    @SuppressWarnings("all")
     public void buildInitialisationCommands() {
         final List<Command> commands = tested.buildInitialisationCommands();
-        assertEquals(2, commands.size());
-
+        assertEquals(1, commands.size());
         final AddNodeCommand addNodeCommand = (AddNodeCommand) commands.get(0);
-        final UpdateElementPropertyValueCommand updatePropertyCommand = (UpdateElementPropertyValueCommand) commands.get(1);
-
         assertEquals(addNodeCommand.getCandidate(), diagramNode);
-        assertEquals(updatePropertyCommand.getElement(), diagramNode);
-        assertEquals(updatePropertyCommand.getPropertyId(), ADHOC_ID);
-        assertEquals(updatePropertyCommand.getValue(), true);
     }
 }
\ No newline at end of file
